@@ -11,7 +11,7 @@
     copyright: (C) 2002 by Dario Abatianni
     email:     eisfuchs@tigress.com
 
-    $Id: channel.cpp,v 1.53 2003/02/23 18:09:27 eisfuchs Exp $
+    $Id: channel.cpp,v 1.62 2003/03/19 16:14:44 eisfuchs Exp $
 */
 
 #include <qvbox.h>
@@ -41,7 +41,7 @@ Channel::Channel(QWidget* parent) : ChatWindow(parent)
   ops=0;
   completionPosition=0;
   nickChangeDialog=0;
-  topic="";
+  topic=QString::null;
 
   quickButtonsChanged=false;
   quickButtonsState=false;
@@ -115,7 +115,6 @@ Channel::Channel(QWidget* parent) : ChatWindow(parent)
   showModeButtons(KonversationApplication::preferences.getShowModeButtons());
 
   setTextView(new IRCView(topicViewNicksGrid,NULL));  // Server will be set later in setServer()
-
   // The box that holds the Nick List and the quick action buttons
   QVBox* nickListButtons=new QVBox(splitter);
   nickListButtons->setSpacing(spacing());
@@ -127,9 +126,9 @@ Channel::Channel(QWidget* parent) : ChatWindow(parent)
   nicknameListView->setSelectionModeExt(KListView::Extended);
   nicknameListView->setAllColumnsShowFocus(true);
   nicknameListView->setSorting(1,true);
-  nicknameListView->addColumn("",2);
-  nicknameListView->addColumn("");
-  nicknameListView->addColumn("");
+  nicknameListView->addColumn(QString::null,2);
+  nicknameListView->addColumn(QString::null);
+  nicknameListView->addColumn(QString::null);
   nicknameListView->header()->hide();
   nicknameListView->setFont(KonversationApplication::preferences.getListFont());
 
@@ -141,10 +140,10 @@ Channel::Channel(QWidget* parent) : ChatWindow(parent)
   for(int index=0;index<8;index++)
   {
     // generate empty buttons first, text will be added by updateQuickButtons() later
-    QuickButton* newQuickButton=new QuickButton("","",buttonsGrid);
+    QuickButton* newQuickButton=new QuickButton(QString::null,QString::null,buttonsGrid);
     buttonList.append(newQuickButton);
 
-    connect(newQuickButton,SIGNAL (clicked(QString)),this,SLOT (quickButtonClicked(QString)) );
+    connect(newQuickButton,SIGNAL (clicked(const QString &)),this,SLOT (quickButtonClicked(const QString &)) );
   }
 
   updateQuickButtons(KonversationApplication::preferences.getButtonList());
@@ -193,8 +192,9 @@ Channel::Channel(QWidget* parent) : ChatWindow(parent)
   connect(channelInput,SIGNAL (textPasted(QString)),this,SLOT (textPasted(QString)) );
   
   connect(textView,SIGNAL (newText()),this,SLOT (newTextInView()) );
-  connect(textView,SIGNAL (newURL(QString)),this, SLOT (urlCatcher(QString)) );
+  connect(textView,SIGNAL (newURL(const QString &)),this, SLOT (urlCatcher(const QString &)) );
   connect(textView,SIGNAL (gotFocus()),this,SLOT (adjustFocus()) );
+  connect(textView,SIGNAL (sendFile()),this,SLOT (sendFileMenu()) );
 
   connect(nicknameListView,SIGNAL (popupCommand(int)),this,SLOT (popupCommand(int)) );
   connect(nicknameListView,SIGNAL (doubleClicked(QListViewItem*)),this,SLOT (doubleClickCommand(QListViewItem*)) );
@@ -242,6 +242,7 @@ void Channel::textPasted(QString text)
 {
   if(server)
   {
+    // TODO: make sure that lines starting with / get extended to //
     QStringList multiline=QStringList::split('\n',text);
     for(unsigned int index=0;index<multiline.count();index++) sendChannelText(multiline[index]);
   }
@@ -395,7 +396,7 @@ void Channel::completeNick()
     /* did we find any pattern? */
     if(pattern && pattern.length())
     {
-      QString foundNick="";
+      QString foundNick(QString::null);
       /* Try to find matching nickname in list of names */
       do
       {
@@ -449,11 +450,16 @@ void Channel::setKey(const QString& newKey)
   key=newKey;
 }
 
-const QString& Channel::getKey()
+QString Channel::getKey()
 {
   return key;
 }
 
+void Channel::sendFileMenu()
+{
+  emit sendFile();
+}
+
 void Channel::channelTextEntered()
 {
   QString line=channelInput->text();
@@ -473,7 +479,7 @@ void Channel::sendChannelText(const QString& sendLine)
 
   // Is there something we need to display for ourselves?
   QString output=filter.parse(server->getNickname(),line,getName());
-  if(output!="")
+  if(!output.isEmpty())
   {
     if(filter.isAction()) appendAction(server->getNickname(),output);
     else if(filter.isCommand()) appendCommandMessage(filter.getType(),output);
@@ -496,7 +502,7 @@ void Channel::setNickname(const QString& newNickname)
   nicknameButton->setText(newNickname);
 }
 
-const QStringList& Channel::getSelectedNicksList()
+QStringList Channel::getSelectedNicksList()
 {
   selectedNicksList.clear();
   Nick* nick=nicknameList.first();
@@ -518,7 +524,7 @@ void Channel::modeButtonClicked(int id,bool on)
   server->queue(command);
 }
 
-void Channel::quickButtonClicked(QString buttonText)
+void Channel::quickButtonClicked(const QString &buttonText)
 {
   // parse wildcards (toParse,nickname,channelName,nickList,queryName,parameter)
   QString out=server->parseWildcards(buttonText,server->getNickname(),getName(),getKey(),getSelectedNicksList(),0,0);
@@ -536,12 +542,12 @@ void Channel::quickButtonClicked(QString buttonText)
   else channelInput->setText(out);
 }
 
-void Channel::urlCatcher(QString url)
+void Channel::urlCatcher(const QString &url)
 {
   KonversationApplication::storeURL(url);
 }
 
-void Channel::addNickname(QString& nickname,QString& hostmask,bool op,bool voice)
+void Channel::addNickname(const QString& nickname,const QString& hostmask,bool op,bool voice)
 {
   Nick* nick=0;
   Nick* lookNick=nicknameList.first();
@@ -577,7 +583,7 @@ void Channel::addNickname(QString& nickname,QString& hostmask,bool op,bool voice
   }
 }
 
-void Channel::renameNick(QString& nickname,QString& newNick)
+void Channel::renameNick(const QString& nickname,const QString& newNick)
 {
   /* Did we change our nick name? */
   if(nickname==server->getNickname())
@@ -594,7 +600,7 @@ void Channel::renameNick(QString& nickname,QString& newNick)
   else nick->setNickname(newNick);
 }
 
-void Channel::joinNickname(QString& nickname,QString& hostmask)
+void Channel::joinNickname(const QString& nickname,const QString& hostmask)
 {
   /* Did we join this channel ourselves? */
   if(nickname==server->getNickname())
@@ -609,7 +615,7 @@ void Channel::joinNickname(QString& nickname,QString& hostmask)
   }
 }
 
-void Channel::removeNick(QString& nickname,QString& reason,bool quit)
+void Channel::removeNick(const QString &nickname, const QString &reason, bool quit)
 {
   if(nickname==server->getNickname())
   {
@@ -635,7 +641,7 @@ void Channel::removeNick(QString& nickname,QString& reason,bool quit)
   }
 }
 
-void Channel::kickNick(QString& nickname,QString& kicker,QString& reason)
+void Channel::kickNick(const QString &nickname, const QString &kicker, const QString &reason)
 {
   if(nickname==server->getNickname())
   {
@@ -673,7 +679,7 @@ void Channel::kickNick(QString& nickname,QString& kicker,QString& reason)
   }
 }
 
-Nick* Channel::getNickByName(QString& lookname)
+Nick* Channel::getNickByName(const QString &lookname)
 {
   Nick* nick=nicknameList.first();
   while(nick)
@@ -683,6 +689,7 @@ Nick* Channel::getNickByName(QString& lookname)
   }
   return 0;
 }
+
 void Channel::adjustNicks(int value)
 {
   nicks+=value;
@@ -701,7 +708,7 @@ void Channel::updateNicksOps()
   nicksOps->setText(i18n("%1 %2 / %3 %4").arg(nicks).arg((nicks==1) ? i18n("Nick") : i18n("Nicks")).arg(ops).arg((ops==1) ? i18n("Op") : i18n("Ops")));
 }
 
-void Channel::setTopic(QString& newTopic)
+void Channel::setTopic(const QString &newTopic)
 {
   appendCommandMessage(i18n("Topic"),i18n("The channel topic is \"%1\".").arg(newTopic));
   if(topic!=newTopic)
@@ -715,7 +722,8 @@ void Channel::setTopic(QString& newTopic)
 
     if(newTopic.length()>80)
     {
-      QString toolTip=newTopic.replace(QRegExp("&",false,true),"&amp;").
+      QString toolTip=newTopic;
+      toolTip.replace(QRegExp("&",false,true),"&amp;").
                                replace(QRegExp("<",false,true),"&lt;").
                                replace(QRegExp(">",false,true),"&gt;");
 
@@ -724,7 +732,7 @@ void Channel::setTopic(QString& newTopic)
   }
 }
 
-void Channel::setTopic(QString& nickname,QString& newTopic) // Overloaded
+void Channel::setTopic(const QString &nickname, const QString &newTopic) // Overloaded
 {
   if(nickname==server->getNickname())
     appendCommandMessage(i18n("Topic"),i18n("You set the channel topic to \"%1\".").arg(newTopic));
@@ -739,19 +747,18 @@ void Channel::setTopic(QString& nickname,QString& newTopic) // Overloaded
   QToolTip::remove(topicLine);
   if(newTopic.length()>80)
   {
-    QString toolTip=newTopic.replace(QRegExp("&",false,true),"&amp;").
+    QString toolTip=newTopic;
+    toolTip.replace(QRegExp("&",false,true),"&amp;").
                              replace(QRegExp("<",false,true),"&lt;").
                              replace(QRegExp(">",false,true),"&gt;");
 
     QToolTip::add(topicLine,"<qt>"+toolTip+"</qt>");
   }
-
-  if(newTopic.length()>80) QToolTip::add(topicLine,"<qt>"+newTopic+"</qt>");
 }
 
-void Channel::updateMode(QString& sourceNick,char mode,bool plus,QString& parameter)
+void Channel::updateMode(const QString &sourceNick, char mode, bool plus, const QString &parameter)
 {
-  QString message="";
+  QString message(QString::null);
   Nick* nick;
 
   bool fromMe=false;
@@ -767,7 +774,13 @@ void Channel::updateMode(QString& sourceNick,char mode,bool plus,QString& parame
     case 'o':
       if(plus)
       {
-        if(fromMe) message=i18n("You give channel operator privileges to %1.").arg(parameter);
+        if(fromMe)
+        {
+          if(toMe)
+            message=i18n("You give channel operator privileges to yourself.");
+          else
+            message=i18n("You give channel operator privileges to %1.").arg(parameter);
+        }
         else
         {
           if(toMe)
@@ -785,7 +798,13 @@ void Channel::updateMode(QString& sourceNick,char mode,bool plus,QString& parame
           else
             message=i18n("You take channel operator privileges from %1.").arg(parameter);
         }
-        else message=i18n("%1 takes channel operator privileges from %2.").arg(sourceNick).arg(parameter);
+        else
+        {
+          if(toMe)
+            message=i18n("%1 takes channel operator privileges from you.").arg(sourceNick);
+          else
+            message=i18n("%1 takes channel operator privileges from %2.").arg(sourceNick).arg(parameter);
+        }
       }
       nick=getNickByName(parameter);
       if(nick)
@@ -801,30 +820,28 @@ void Channel::updateMode(QString& sourceNick,char mode,bool plus,QString& parame
     case 'v':
       if(plus)
       {
-        if(fromMe) message=i18n("You give %1 the permission to talk.").arg(parameter);
+        if(fromMe)
+        {
+          if(toMe) message=i18n("You give yourself the permission to talk.");
+          else     message=i18n("You give %1 the permission to talk.").arg(parameter);
+        }
         else
         {
-          if(toMe)
-            message=i18n("%1 gives you the permission to talk.").arg(sourceNick);
-          else
-            message=i18n("%1 gives %2 the permission to talk.").arg(sourceNick).arg(parameter);
+          if(toMe) message=i18n("%1 gives you the permission to talk.").arg(sourceNick);
+          else     message=i18n("%1 gives %2 the permission to talk.").arg(sourceNick).arg(parameter);
         }
       }
       else
       {
         if(fromMe)
         {
-          if(toMe)
-            message=i18n("You take the permission to talk from yourself.");
-          else
-            message=i18n("You take the permission to talk from %1.").arg(parameter);
+          if(toMe) message=i18n("You take the permission to talk from yourself.");
+          else     message=i18n("You take the permission to talk from %1.").arg(parameter);
         }
         else
         {
-          if(toMe)
-            message=i18n("%1 takes the permission to talk from you.").arg(sourceNick);
-          else
-            message=i18n("%1 takes the permission to talk from %2.").arg(sourceNick).arg(parameter);
+          if(toMe) message=i18n("%1 takes the permission to talk from you.").arg(sourceNick);
+          else     message=i18n("%1 takes the permission to talk from %2.").arg(sourceNick).arg(parameter);
         }
       }
       nick=getNickByName(parameter);
@@ -898,7 +915,7 @@ void Channel::updateMode(QString& sourceNick,char mode,bool plus,QString& parame
         if(fromMe) message=i18n("You remove the 'quiet' channel mode.");
         else message=i18n("%1 removes the 'quiet' channel mode.").arg(sourceNick);
       }
-/*      modeQ->setDown(plus); */
+
     break;
 
     case 'p':
@@ -1004,11 +1021,11 @@ void Channel::updateMode(QString& sourceNick,char mode,bool plus,QString& parame
       }
     break;
   }
-  if(message!="") appendCommandMessage(i18n("Mode"),message);
+  if(!message.isEmpty()) appendCommandMessage(i18n("Mode"),message);
   updateModeWidgets(mode,plus,parameter);
 }
 
-void Channel::updateModeWidgets(char mode,bool plus,QString& parameter)
+void Channel::updateModeWidgets(char mode, bool plus, const QString &parameter)
 {
   ModeButton* widget=0;
 
@@ -1117,9 +1134,15 @@ void Channel::updateFonts()
 {
   kdDebug() << "Channel::updateFonts()" << endl;
 
+  topicLine->setFont(KonversationApplication::preferences.getTextFont());
+  limit->setFont(KonversationApplication::preferences.getTextFont());
+  nicknameButton->setFont(KonversationApplication::preferences.getTextFont());
+  channelInput->setFont(KonversationApplication::preferences.getTextFont());
+  logCheckBox->setFont(KonversationApplication::preferences.getTextFont());
   getTextView()->setFont(KonversationApplication::preferences.getTextFont());
   getTextView()->setPaper(QColor("#"+KonversationApplication::preferences.getTextViewBackground()));
 
+  nicksOps->setFont(KonversationApplication::preferences.getListFont());
   nicknameListView->setFont(KonversationApplication::preferences.getListFont());
 }
 
@@ -1127,18 +1150,18 @@ void Channel::openNickChangeDialog()
 {
   if(!nickChangeDialog)
   {
-    Identity identity=server->getIdentity();
+    const Identity *identity=server->getIdentity();
 
     nickChangeDialog=new NickChangeDialog(this,server->getNickname(),
-                                          identity.getNicknameList(),
+                                          identity->getNicknameList(),
                                           KonversationApplication::preferences.getNicknameSize());
     connect(nickChangeDialog,SIGNAL (closeDialog(QSize)),this,SLOT (closeNickChangeDialog(QSize)) );
-    connect(nickChangeDialog,SIGNAL (newNickname(QString)),this,SLOT (changeNickname(QString)) );
+    connect(nickChangeDialog,SIGNAL (newNickname(const QString&)),this,SLOT (changeNickname(const QString&)) );
     nickChangeDialog->show();
   }
 }
 
-void Channel::changeNickname(QString newNickname)
+void Channel::changeNickname(const QString& newNickname)
 {
   server->queue("NICK "+newNickname);
 }
