@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: dccpanel.h,v 1.10 2003/01/18 18:58:59 eisfuchs Exp $
+  $Id: dccpanel.h,v 1.11 2003/03/02 12:01:21 eisfuchs Exp $
 */
 
 #ifndef DCCPANEL_H
@@ -40,12 +40,16 @@ class DccPanel : public ChatWindow
     DccTransfer* getTransferByPort(QString port,DccTransfer::DccType type);
     DccTransfer* getTransferByName(QString name,DccTransfer::DccType type);
 
+  signals:
+    void requestDccSend();
+
   public slots:
     void adjustFocus();
     
   protected slots:
     void acceptDcc();
     void runDcc();
+    void sendDcc();
     void abortDcc();
     void removeDcc();
     void dccSelected();
