@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: dcctransfer.h,v 1.16 2003/01/09 20:18:06 eisfuchs Exp $
+  $Id: dcctransfer.h,v 1.17 2003/03/10 20:18:15 eisfuchs Exp $
 */
 
 
@@ -77,10 +77,10 @@ class DccTransfer : public QObject, public KListViewItem
     unsigned long getBufferSize();
 
   signals:
-    void send(QString partner,QString fileName,QString ip,QString port,unsigned long size);
-    void resumeGet(QString partner,QString fileName,QString port,int startAt);
-    void dccGetDone(QString fileName);
-    void dccSendDone(QString fileName);
+    void send(const QString& partner,const QString& fileName,const QString& ip,const QString& port,unsigned long size);
+    void resumeGet(const QString& partner,const QString& fileName,const QString& port,int startAt);
+    void dccGetDone(const QString& fileName);
+    void dccSendDone(const QString& fileName);
 
   public slots:
     void startGet();
