@@ -21,7 +21,6 @@
 
 #include <qstring.h>
 
-#include <iostream.h>
 #include <stdlib.h>
 
 #include "highlightdialog.h"
@@ -134,7 +133,7 @@ void HighlightDialog::addHighlight()
 {
 	if((selectedHighlightViewItem = HighlightBrowser->selectedItem()) == 0)
 	{
-		if((InputLine->text() != ""))
+		if(!InputLine->text().isEmpty())
 		{
 			if(HighlightBrowser->findItem(InputLine->text(), 0, Qt::ExactMatch) != 0)
 			{
@@ -145,7 +144,7 @@ void HighlightDialog::addHighlight()
 			currentHighlight = new Highlight(InputLine->text(), ColorSelection->color());
 			highlightList.append(currentHighlight);
 			currentHighlightViewItem = new HighlightViewItem(HighlightBrowser, currentHighlight);
-			InputLine->setText("");
+			InputLine->setText(QString::null);
 		}
 		else noEmptyPatterns();
 	}
@@ -168,7 +167,7 @@ void HighlightDialog::changeHighlightColor(const QColor& passed_itemColor)
 
 void HighlightDialog::changeColorSelectionColor(QListViewItem* passed_selectedHighlightViewItem)
 {
-	selectedHighlightViewItem = (HighlightViewItem*) passed_selectedHighlightViewItem;
+	selectedHighlightViewItem = static_cast<HighlightViewItem*>(passed_selectedHighlightViewItem);
 	if(selectedHighlightViewItem != 0)
 	{
 		ColorSelection->setColor(selectedHighlightViewItem->getColor());
@@ -180,16 +179,16 @@ void HighlightDialog::removeHighlight()
 	if(selectedHighlightViewItem != 0)
 	{
 		HighlightBrowser->removeItem(HighlightBrowser->selectedItem());
-		InputLine->setText("");
+		InputLine->setText(QString::null);
 	}
 }
 
 void HighlightDialog::unselectHighlight(QListViewItem* passed_selectedHighlightViewItem)
 {
-	if((selectedHighlightViewItem = (HighlightViewItem*) passed_selectedHighlightViewItem) == oldSelectedHighlightViewItem)
+	if((selectedHighlightViewItem = static_cast<HighlightViewItem*>(passed_selectedHighlightViewItem)) == oldSelectedHighlightViewItem)
 	{
 		HighlightBrowser->clearSelection();
-		InputLine->setText("");
+		InputLine->setText(QString::null);
 		oldSelectedHighlightViewItem = 0;
 	}
 	else oldSelectedHighlightViewItem = selectedHighlightViewItem;
@@ -197,7 +196,7 @@ void HighlightDialog::unselectHighlight(QListViewItem* passed_selectedHighlightV
 
 void HighlightDialog::updateInputLine(QListViewItem* passed_selectedHighlightViewItem)
 {
-	selectedHighlightViewItem = (HighlightViewItem*) passed_selectedHighlightViewItem;
+	selectedHighlightViewItem = static_cast<HighlightViewItem*>(passed_selectedHighlightViewItem);
 	if(selectedHighlightViewItem != 0)
 	{
 		InputLine->setText(selectedHighlightViewItem->getText());
@@ -220,20 +219,19 @@ void HighlightDialog::updateHighlight(const QString& passed_InputLineText)
 
 void HighlightDialog::changeHighlightText()
 {
-// EIS: if-Bedingung fr beide Abfragen schachteln, um den Segfault zu beheben
   if((selectedHighlightViewItem = HighlightBrowser->selectedItem()) != 0)
   {
-		if(selectedHighlightViewItem->getText() != "")
-  	{
-  		highlightEdited = false;
-	  	InputLine->setText("");
-		  emit highlightChanged((QListViewItem*) selectedHighlightViewItem);
-  	}
-  	else if(selectedHighlightViewItem->getText() == "") noEmptyPatterns();
+    if(!selectedHighlightViewItem->getText().isEmpty())
+    {
+      highlightEdited = false;
+      InputLine->setText(QString::null);
+      emit highlightChanged(static_cast<QListViewItem*>(selectedHighlightViewItem));
+    }
+    else noEmptyPatterns();
   }
 }
 
-void HighlightDialog::undoHighlightTextChange(QListViewItem* passed_selectedHighlightViewItem)
+void HighlightDialog::undoHighlightTextChange(QListViewItem */*passed_selectedHighlightViewItem*/)
 {
 	if(highlightEdited == true)
 	{
