@@ -11,17 +11,24 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: ircserversocket.cpp,v 1.5 2003/01/25 19:22:57 eisfuchs Exp $
+  $Id: ircserversocket.cpp,v 1.6 2003/02/27 13:50:32 eisfuchs Exp $
 */
 
 #include "ircserversocket.h"
 
 #include <kdebug.h>
 
-IRCServerSocket::IRCServerSocket(const char *server,unsigned short int port,int timeout) :
-                 KExtendedSocket(server,port)
+IRCServerSocket::IRCServerSocket() :
+                 KExtendedSocket()
 {
-  kdDebug() << "IRCServerSocket::IRCServerSocket(" << server << "," << port << "): Socket=" << fd() << endl;
+  kdDebug() << "IRCServerSocket::IRCServerSocket()" << endl;
+}
+
+IRCServerSocket::IRCServerSocket(const char *server,unsigned short int port,int timeout) :
+                 KExtendedSocket(server,port,KExtendedSocket::inetSocket)
+{
+  setTimeout(timeout);
+  kdDebug() << "IRCServerSocket::IRCServerSocket(" << server << "," << port << ")" << endl;
 }
 
 IRCServerSocket::~IRCServerSocket()
