@@ -11,13 +11,14 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: ircview.h,v 1.8 2003/01/28 12:20:49 eisfuchs Exp $
+  $Id: ircview.h,v 1.12 2003/03/18 14:34:57 eisfuchs Exp $
 */
 
 #ifndef IRCVIEW_H
 #define IRCVIEW_H
 
 #include <qevent.h>
+#include <qpopupmenu.h>
 
 #include <ktextbrowser.h>
 
@@ -38,14 +39,23 @@ class IRCView : public KTextBrowser
     void clear();
     void setServer(Server* server);
 
+    enum PopupIDs
+    {
+      Copy,SelectAll,
+      Search,
+      SendFile
+    };
+
   signals:
     void newText();      // Notify container of new text
-    void newURL(QString url);
+    void newURL(const QString &url);
     void gotFocus();     // So we can set focus to input line
     void textToLog(const QString& text);
+    void sendFile();
 
   public slots:
     void append(const char* nick,const char* message);
+    void appendRaw(const char* message);
     void appendQuery(const char* nick,const char* message);
     void appendAction(const char* nick,const char* message);
     void appendServerMessage(const char* type,const char* message);
@@ -62,8 +72,16 @@ class IRCView : public KTextBrowser
 
     bool eventFilter(QObject* object,QEvent* event);
 
+    bool contextMenu(QContextMenuEvent* ce);
+    void search();
+
+    // used by search function
+    int findParagraph;
+    int findIndex;
+    
     QString buffer;
     Server *server;
+    QPopupMenu* popup;
 };
 
 #endif
