@@ -11,14 +11,15 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: konversationapplication.cpp,v 1.52 2003/02/20 17:00:59 eisfuchs Exp $
+  $Id: konversationapplication.cpp,v 1.66 2003/03/23 14:33:30 eisfuchs Exp $
 */
 
 #include <kdebug.h>
-
 #include <qregexp.h>
+#include <dcopclient.h>
 
 #include "konversationapplication.h"
+#include "konvdcop.h"
 #include "serverwindow.h"
 
 // include static variables
@@ -57,20 +58,53 @@ KonversationApplication::KonversationApplication()
     connect(prefsDialog,SIGNAL (cancelClicked()),this,SLOT (quitKonversation()) );
     connect(prefsDialog,SIGNAL (prefsChanged()),this,SLOT (saveOptions()) );
 
-    // TODO: Check if this serverList is needed at all
-    serverList.setAutoDelete(true);     // delete items when they are removed
+    serverList.setAutoDelete(false);     // don't delete items when they are removed
 
     prefsDialog->show();
 
     connect(&preferences,SIGNAL (requestServerConnection(int)),this,SLOT (connectToAnotherServer(int)) );
     connect(&preferences,SIGNAL (requestSaveOptions()),this,SLOT (saveOptions()) );
   }
+  // prepare dcop interface
+  dcopObject=new KonvDCOP;
+  (void)new KonvIdentDCOP;
+  (void)new KonvPrefsDCOP;
+  if(dcopObject)
+  {
+    connect(dcopObject,SIGNAL (dcopSay(const QString&,const QString&,const QString&)),
+                    this,SLOT (dcopSay(const QString&,const QString&,const QString&)) );
+    connect(dcopObject,SIGNAL (dcopInfo(const QString&)),
+                    this,SLOT (dcopInfo(const QString&)) );
+  }
 }
 
 KonversationApplication::~KonversationApplication()
 {
   kdDebug() << "KonversationApplication::~KonversationApplication()" << endl;
   saveOptions(false);
+  delete dcopObject;
+}
+
+void KonversationApplication::dcopSay(const QString& server,const QString& target,const QString& command)
+{
+  Server* lookServer=serverList.first();
+  while(lookServer)
+  {
+    if(lookServer->getServerName()==server)
+    {
+      lookServer->dcopSay(target,command);
+      // break out of while loop
+      lookServer=0;
+    }
+    else lookServer=serverList.next();
+  }
+}
+
+void KonversationApplication::dcopInfo(const QString& string)
+{
+  Server* lookServer=serverList.first();
+  if(lookServer)
+    lookServer->dcopInfo(string);
 }
 
 void KonversationApplication::connectToServer(int id)
@@ -99,27 +133,50 @@ void KonversationApplication::connectToAnotherServer(int id)
        chosenServer->getPort()==newServer->getPort())
     {
       QString autoJoinChannel=chosenServer->getChannelName();
-      if(autoJoinChannel!="")
-      {
-        newServer->setAutoJoin(true);
-        newServer->setAutoJoinChannel(autoJoinChannel);
-        newServer->setAutoJoinChannelKey(chosenServer->getChannelKey());
-      }
-      else newServer->setAutoJoin(false);
 
-      newServer->connectToIRCServer();
+      if(newServer->isConnected())
+      {
+        if(!autoJoinChannel.isEmpty())
+          newServer->queue("JOIN "+autoJoinChannel+" "+chosenServer->getChannelKey());
+      }
+      else
+      {
+        if(!autoJoinChannel.isEmpty())
+        {
+          newServer->setAutoJoin(true);
+          newServer->setAutoJoinChannel(newServer->getAutoJoinChannel()+" "+autoJoinChannel);
+          newServer->setAutoJoinChannelKey(newServer->getAutoJoinChannelKey()+" "+chosenServer->getChannelKey());
+        }
+        else newServer->setAutoJoin(false);
+
+        newServer->connectToIRCServer();
+      }
       return;
     }
 
     newServer=serverList.next();
-  }
+  } // endwhile
   // We came this far, so generate a new server
+
   newServer=new Server(id);
   serverList.append(newServer);
+
+  connect(newServer,SIGNAL(deleted(Server*)),this,SLOT(removeServer(Server*)));
+
   connect(newServer->getServerWindow(),SIGNAL(prefsChanged()),this,SLOT(saveOptions()));
   connect(newServer->getServerWindow(),SIGNAL(openPrefsDialog()),this,SLOT(openPrefsDialog()));
 }
 
+void KonversationApplication::removeServer(Server* server)
+{
+  Server* lookServer=serverList.first();
+  while(lookServer)
+  {
+    if(lookServer==server) serverList.remove();
+    else lookServer=serverList.next();
+  }
+}
+
 void KonversationApplication::quitKonversation()
 {
   kdDebug() << "KonversationApplication::quitKonversation()" << endl;
@@ -147,6 +204,9 @@ void KonversationApplication::readOptions()
   // Status bar settings
   preferences.serverWindowStatusBarStatus=config->readBoolEntry("ServerWindowStatusBarStatus",true);
 
+  // Menu bar settings
+  preferences.serverWindowMenuBarStatus=config->readBoolEntry("ServerWindowMenuBarStatus",true);
+
   // Window geometries
   preferences.setServerWindowSize(config->readSizeEntry("Geometry"));
   preferences.setHilightSize(config->readSizeEntry("HilightGeometry"));
@@ -164,6 +224,9 @@ void KonversationApplication::readOptions()
   // Beep
   preferences.setBeep(config->readBoolEntry("Beep",preferences.getBeep()));
   
+  // Raw log window
+  preferences.setRawLog(config->readBoolEntry("RawLog",preferences.getRawLog()));
+  
   // Appearance
   config->setGroup("Appearance");
   // Fonts
@@ -173,6 +236,7 @@ void KonversationApplication::readOptions()
   preferences.setTimestampFormat(config->readEntry("TimestampFormat",preferences.getTimestampFormat()));
   preferences.setShowQuickButtons(config->readBoolEntry("ShowQuickButtons",preferences.getShowQuickButtons()));
   preferences.setShowModeButtons(config->readBoolEntry("ShowModeButtons",preferences.getShowModeButtons()));
+  preferences.setCloseButtonsOnTabs(config->readBoolEntry("CloseButtonsOnTabs",preferences.getCloseButtonsOnTabs()));
   preferences.setCodec(config->readEntry("Codec",preferences.getCodec()));
 
   preferences.setUseSpacing(config->readBoolEntry("UseSpacing",preferences.getUseSpacing()));
@@ -224,6 +288,9 @@ void KonversationApplication::readOptions()
       QString nickList=config->readEntry("Nicknames");
       newIdentity->setNicknameList(QStringList::split(",",nickList));
 
+      newIdentity->setBot(config->readEntry("Bot"));
+      newIdentity->setPassword(config->readEntry("Password"));
+
       newIdentity->setShowAwayMessage(config->readBoolEntry("ShowAwayMessage"));
       newIdentity->setAwayMessage(config->readEntry("AwayMessage"));
       newIdentity->setReturnMessage(config->readEntry("ReturnMessage"));
@@ -256,7 +323,7 @@ void KonversationApplication::readOptions()
   config->setGroup("Notify List");
   preferences.setNotifyDelay(config->readNumEntry("NotifyDelay",20));
   preferences.setUseNotify(config->readBoolEntry("UseNotify",true));
-  QString notifyList=config->readEntry("NotifyList","");
+  QString notifyList=config->readEntry("NotifyList",QString::null);
   preferences.setNotifyList(QStringList::split(' ',notifyList));
 
   // Server List
@@ -296,14 +363,14 @@ void KonversationApplication::readOptions()
 
   preferences.setHilightNick(config->readBoolEntry("HilightNick",preferences.getHilightNick()));
   hilight=config->readEntry("HilightNickColor");
-  if(hilight=="")
+  if(hilight.isEmpty())
     preferences.setHilightNickColor(preferences.getHilightNickColor().name());
   else
     preferences.setHilightNickColor("#"+hilight);
 
   preferences.setHilightOwnLines(config->readBoolEntry("HilightOwnLines",preferences.getHilightOwnLines()));
   hilight=config->readEntry("HilightOwnLinesColor");
-  if(hilight=="")
+  if(hilight.isEmpty())
     preferences.setHilightOwnLinesColor(preferences.getHilightOwnLinesColor().name());
   else
     preferences.setHilightOwnLinesColor("#"+hilight);
@@ -381,10 +448,13 @@ void KonversationApplication::saveOptions(bool updateGUI)
 
   config->writeEntry("ServerWindowStatusBarStatus",preferences.serverWindowStatusBarStatus);
 
+  config->writeEntry("ServerWindowMenuBarStatus",preferences.serverWindowMenuBarStatus);
+
   config->writeEntry("ChannelDoubleClickAction",preferences.getChannelDoubleClickAction());
   config->writeEntry("NotifyDoubleClickAction",preferences.getNotifyDoubleClickAction());
 
   config->writeEntry("Beep",preferences.getBeep());
+  config->writeEntry("RawLog",preferences.getRawLog());
   
   config->setGroup("Appearance");
 
@@ -394,6 +464,7 @@ void KonversationApplication::saveOptions(bool updateGUI)
   config->writeEntry("TimestampFormat",preferences.getTimestampFormat());
   config->writeEntry("ShowQuickButtons",preferences.getShowQuickButtons());
   config->writeEntry("ShowModeButtons",preferences.getShowModeButtons());
+  config->writeEntry("CloseButtonsOnTabs",preferences.getCloseButtonsOnTabs());
   config->writeEntry("Codec",preferences.getCodec());
 
   config->writeEntry("UseSpacing",preferences.getUseSpacing());
@@ -441,6 +512,8 @@ void KonversationApplication::saveOptions(bool updateGUI)
     config->writeEntry("Ident",identity->getIdent());
     config->writeEntry("Realname",identity->getRealName());
     config->writeEntry("Nicknames",identity->getNicknameList());
+    config->writeEntry("Bot",identity->getBot());
+    config->writeEntry("Password",identity->getPassword());
     config->writeEntry("ShowAwayMessage",identity->getShowAwayMessage());
     config->writeEntry("AwayMessage",identity->getAwayMessage());
     config->writeEntry("ReturnMessage",identity->getReturnMessage());
@@ -548,9 +621,10 @@ void KonversationApplication::saveOptions(bool updateGUI)
     Server* lookServer=serverList.first();
     while(lookServer)
     {
-      // TODO: This also updates the background color! We must finally
+      // TODO: updateFonts() also updates the background color and more stuff! We must finally
       // find a way to do all this with signals / slots!
       lookServer->updateFonts();
+
       lookServer->setShowQuickButtons(preferences.getShowQuickButtons());
       lookServer->setShowModeButtons(preferences.getShowModeButtons());
       lookServer=serverList.next();
@@ -558,8 +632,7 @@ void KonversationApplication::saveOptions(bool updateGUI)
   }
 }
 
-
-void KonversationApplication::storeURL(QString& url)
+void KonversationApplication::storeURL(const QString &url)
 {
   urlList.append(url);
 }
@@ -576,6 +649,12 @@ void KonversationApplication::openPrefsDialog()
 
     prefsDialog->show();
   }
+  else
+  {
+    prefsDialog->show();
+    prefsDialog->raise();
+    prefsDialog->setActiveWindow();
+  }
 }
 
 void KonversationApplication::syncPrefs()
@@ -589,5 +668,40 @@ void KonversationApplication::closePrefsDialog()
   prefsDialog=0;
 }
 
-#include "konversationapplication.moc"
+bool KonversationApplication::emitDCOPSig(const QString &appId, const QString &objId, const QString &signal, QByteArray &data)
+{
+  kdDebug() << "emitDCOPSig (" << signal << ")" << endl;
+  //dcopObject->emitDCOPSignal(signal, data);
+  QByteArray replyData;
+  QCString replyType;
+  if (!KApplication::dcopClient()->call(appId.ascii(), objId.ascii(), signal.ascii() /*must have prototype*/,
+					data, replyType, replyData)) {
+    qDebug("there was some error using DCOP.");
+    return true; // Keep processing filters
+  } else {
+    QDataStream reply(replyData, IO_ReadOnly);
+    if (replyType == "bool") {
+      bool result;
+      reply >> result;
+      return result;
+    } else {
+      qDebug("doIt returned an unexpected type of reply!");
+      return true; // Keep processing
+    }
+  }
+}
 
+QPtrList<IRCEvent> KonversationApplication::retreiveHooks (EVENT_TYPE a_type)
+{
+  QPtrList<IRCEvent> ret_value;
+  IRCEvent *e;
+
+  for (e = dcopObject->registered_events.first(); e; e = dcopObject->registered_events.next()) {
+    if (e->type == a_type) {
+      ret_value.append(e);
+      }
+    }
+  return ret_value;
+}
+
+#include "konversationapplication.moc"
