@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: konversationapplication.h,v 1.8 2003/02/20 17:01:01 eisfuchs Exp $
+  $Id: konversationapplication.h,v 1.15 2003/03/23 14:33:30 eisfuchs Exp $
 */
 
 #ifndef KONVERSATIONAPPLICATION_H
@@ -20,9 +20,14 @@
 #include <kapp.h>
 #include <ksimpleconfig.h>
 
+#include <qcstring.h>
+
 #include "preferences.h"
 #include "prefsdialog.h"
 #include "server.h"
+#include "event.h"
+
+class KonvDCOP;
 
 /*
   @author Dario Abatianni
@@ -32,12 +37,16 @@ class KonversationApplication : public KApplication
 {
   Q_OBJECT
   public:
+
     static Preferences preferences;
 
     // URL-Catcher
     // TODO: Provide a list of seen URLs
     static QStringList urlList;
-    static void storeURL(QString& url);
+    static void storeURL(const QString &url);
+
+    // Returns a list of signals we should emit
+    QPtrList<IRCEvent> retreiveHooks (EVENT_TYPE type);
 
     KonversationApplication();
     ~KonversationApplication();
@@ -54,9 +63,17 @@ class KonversationApplication : public KApplication
     void openPrefsDialog();
     void closePrefsDialog();
 
+    bool emitDCOPSig(const QString &appId, const QString &objId, const QString &signal, QByteArray &data);
+
+  protected slots:
+    void removeServer(Server* server);
+    void dcopSay(const QString& server,const QString& target,const QString& command);
+    void dcopInfo(const QString& string);
+
   protected:
     QPtrList<Server> serverList;
     PrefsDialog* prefsDialog;
+    KonvDCOP* dcopObject;
 };
 
 #endif
