@@ -12,7 +12,7 @@
              in parts (C) by Trolltech
   email:     eisfuchs@tigress.com
 
-  $Id: ledtabbar.h,v 1.7 2003/02/17 14:00:19 eisfuchs Exp $
+  $Id: ledtabbar.h,v 1.9 2003/03/05 10:17:15 eisfuchs Exp $
 */
 
 #ifndef LEDTABBAR_H
@@ -20,6 +20,8 @@
 
 #include <qtabbar.h>
 
+#include <kpopupmenu.h>
+
 #include "ledtab.h"
 
 /*
@@ -38,6 +40,7 @@ class LedTabBar : public QTabBar
     LedTab* tab(QWidget* widget);
 
     virtual void layoutTabs();
+    void updateTabs();
 
   signals:
     void closeTab(int id);
@@ -46,12 +49,19 @@ class LedTabBar : public QTabBar
     void repaintLED(LedTab* tab);
 
   protected:
+    enum PopupIDs
+    {
+      Label=0,
+      CloseTab
+    };
     // these two come from the original QT source
     virtual void paint( QPainter *, QTab *, bool ) const; // ### not const
     virtual void paintLabel( QPainter*, const QRect&, QTab*, bool ) const;
 
-  protected:
+    void contextMenuEvent(QContextMenuEvent* ce);
     void mouseReleaseEvent(QMouseEvent* e);
+
+    KPopupMenu* popup;
 };
 
 #endif
