@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: ledtabwidget.cpp,v 1.8 2003/02/17 14:00:20 eisfuchs Exp $
+  $Id: ledtabwidget.cpp,v 1.10 2003/03/19 16:14:44 eisfuchs Exp $
 */
 
 #include <kdebug.h>
@@ -73,7 +73,15 @@ void LedTabWidget::tabClosed(int id)
 // reimplemented to avoid casts in active code
 LedTabBar* LedTabWidget::tabBar()
 {
-  return (LedTabBar*) QTabWidget::tabBar();
+  return static_cast<LedTabBar*>(QTabWidget::tabBar());
+}
+
+void LedTabWidget::updateTabs()
+{
+  // reliably redraw the tab bar by resetting the label of the first tab
+  changeTab(page(0),label(0));
+  tabBar()->updateTabs();
+  update();
 }
 
 #include "ledtabwidget.moc"
