@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: ledtabwidget.h,v 1.7 2003/02/17 14:00:21 eisfuchs Exp $
+  $Id: ledtabwidget.h,v 1.9 2003/03/05 00:03:15 eisfuchs Exp $
 */
 
 #ifndef LEDTABWIDGET_H
@@ -37,14 +37,15 @@ class LedTabWidget : public QTabWidget
 
     void addTab(QWidget* child,const QString& label,int color,bool on);
     void changeTabState(QWidget* child,bool state);
+    void connectTabUpdate(QObject* object);
 
   signals:
-    void currentChanged(QWidget* view);
     void closeTab(QWidget* view);
 
   protected slots:
     void tabSelected(int id);
     void tabClosed(int id);
+    void updateTabs();
 
   protected:
     LedTabBar* tabBar();
