@@ -11,23 +11,19 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: nick.cpp,v 1.5 2002/07/27 23:37:16 gismore Exp $
+  $Id: nick.cpp,v 1.7 2003/03/06 15:06:09 eisfuchs Exp $
 */
 
 #include <kdebug.h>
 
 #include "nick.h"
-#include "konversationapplication.h"
 
-Nick::Nick(KListView* listView,QString& nickname,QString& hostmask, bool op, bool voice)
+Nick::Nick(KListView* listView,const QString &nickname, const QString &hostmask, bool op, bool voice)
 {
   kdDebug() << "Nick::Nick(" << nickname << "," << hostmask << ")" << endl;
-	//op = passed_op;
-	//voice = passed_voice;
 
-	//listViewItem=new KListViewItem(listView,(op) ? "@" : (voice) ?  "+" : "-",nickname);
-  listViewItem = new LedListViewItem(listView, nickname, op, voice, KonversationApplication::preferences.getOpLedColor(), 0);
-	setNickname(nickname);
+  listViewItem = new LedListViewItem(listView, nickname,op,voice);
+  setNickname(nickname);
   setHostmask(hostmask);
 
   setOp(op);
@@ -40,7 +36,7 @@ Nick::~Nick()
   delete listViewItem;
 }
 
-void Nick::setNickname(QString& newName)
+void Nick::setNickname(const QString &newName)
 {
   nickname=newName;
   listViewItem->setText(1,newName);
@@ -49,25 +45,11 @@ void Nick::setNickname(QString& newName)
 void Nick::setOp(bool setop)
 {
   op=setop;
-	listViewItem->setState(op, voice);
-/*  if(op==false)
-  {
-    listViewItem->setText(0, (hasVoice()) ? "+" : "-" );
-	}
-  listViewItem->setText(0, "");
-  listViewItem->setState(op);*/
+  listViewItem->setState(op,voice);
 }
 
 void Nick::setVoice(bool setvoice)
 {
   voice=setvoice;
-	listViewItem->setState(op, voice);
-/*  if(voice==true)
-  {
-    listViewItem->setText(0, (op) ? "" : "+" );
-  }
-  else
-  {
-    listViewItem->setText(0, (op) ? "" : "-" );
-  }*/
+  listViewItem->setState(op,voice);
 }
