@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: nick.h,v 1.7 2003/01/28 12:20:49 eisfuchs Exp $
+  $Id: nick.h,v 1.8 2003/03/06 15:06:09 eisfuchs Exp $
 */
 
 #ifndef NICK_H
@@ -29,7 +29,7 @@
 class Nick
 {
   public:
-    Nick(KListView* listView,QString& nickname,QString& hostmask, bool op, bool voice);
+    Nick(KListView* listView, const QString &nickname, const QString &hostmask, bool op, bool voice);
     ~Nick();
 
     bool isOp() { return op; };
@@ -38,10 +38,10 @@ class Nick
     void setVoice(bool setvoice);
     bool isSelected() { return listViewItem->isSelected(); } ;
 
-    QString& getNickname() { return nickname; };
-    QString& getHostmask() { return hostmask; };
-    void setHostmask(QString& newMask) { hostmask=newMask; };
-    void setNickname(QString& newName);
+    QString getNickname() { return nickname; };
+    QString getHostmask() { return hostmask; };
+    void setHostmask(const QString& newMask) { hostmask=newMask; };
+    void setNickname(const QString& newName);
 
   protected:
     bool op;
