@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: nickchangedialog.h,v 1.3 2003/02/10 21:30:29 eisfuchs Exp $
+  $Id: nickchangedialog.h,v 1.4 2003/03/16 18:36:33 eisfuchs Exp $
 */
 
 
@@ -36,7 +36,7 @@ class NickChangeDialog : public KDialogBase
     ~NickChangeDialog();
 
   signals:
-    void newNickname(QString newNick);
+    void newNickname(const QString& newNick);
     void closeDialog(QSize newSize);
 
   protected slots:
