@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: nicksonline.cpp,v 1.4 2003/02/14 15:03:04 eisfuchs Exp $
+  $Id: nicksonline.cpp,v 1.6 2003/03/10 16:24:59 eisfuchs Exp $
 */
 
 #include <qlayout.h>
@@ -25,7 +25,7 @@
 
 #include "nicksonline.h"
 
-NicksOnline::NicksOnline(QSize& newSize)
+NicksOnline::NicksOnline(const QSize& newSize)
 {
   kdDebug() << "NicksOnline::NicksOnline()" << endl;
   nickListView=new KListView(this);
@@ -53,7 +53,7 @@ NicksOnline::~NicksOnline()
   delete nickListView;
 }
 
-void NicksOnline::setOnlineList(QStringList list)
+void NicksOnline::setOnlineList(const QStringList& list)
 {
   nickListView->clear();
   for(unsigned int i=list.count();i!=0;i--)
