@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: nicksonline.h,v 1.3 2003/02/17 14:00:22 eisfuchs Exp $
+  $Id: nicksonline.h,v 1.5 2003/03/10 16:24:59 eisfuchs Exp $
 */
 
 #ifndef NICKSONLINE_H
@@ -30,7 +30,7 @@ class NicksOnline : public QVBox
   Q_OBJECT
 
   public: 
-    NicksOnline(QSize& newSize);
+    NicksOnline(const QSize& newSize);
     ~NicksOnline();
 
   signals:
@@ -39,7 +39,7 @@ class NicksOnline : public QVBox
     void closeClicked(QSize size);
 
   public slots:
-    void setOnlineList(QStringList list);
+    void setOnlineList(const QStringList& list);
     void closeButton();
     
   protected slots:
