@@ -11,13 +11,14 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: prefspageappearance.cpp,v 1.11 2003/02/16 20:03:00 eisfuchs Exp $
+  $Id: prefspageappearance.cpp,v 1.14 2003/03/23 14:33:30 eisfuchs Exp $
 */
 
 #include <qlayout.h>
 #include <qpushbutton.h>
 #include <qhbox.h>
 #include <qcombobox.h>
+#include <qtextcodec.h>
 
 #include <kfontdialog.h>
 #include <kdebug.h>
@@ -32,8 +33,8 @@ PrefsPageAppearance::PrefsPageAppearance(QFrame* newParent,Preferences* newPrefe
   QGridLayout* appearanceLayout=new QGridLayout(parentFrame,3,3,marginHint(),spacingHint());
 
   // Font settings
-  QLabel* textFontLabel=new QLabel(i18n("Text Font:"),parentFrame);
-  QLabel* listFontLabel=new QLabel(i18n("Nickname List Font:"),parentFrame);
+  QLabel* textFontLabel=new QLabel(i18n("Text font:"),parentFrame);
+  QLabel* listFontLabel=new QLabel(i18n("Nickname list font:"),parentFrame);
 
   textPreviewLabel=new QLabel(parentFrame);
   listPreviewLabel=new QLabel(parentFrame);
@@ -45,11 +46,11 @@ PrefsPageAppearance::PrefsPageAppearance(QFrame* newParent,Preferences* newPrefe
   QPushButton* listFontButton=new QPushButton(i18n("Choose..."),parentFrame,"list_font_button");
 
   QLabel* codecLabel=new QLabel(i18n("Encoding"),parentFrame);
-  QComboBox* codecList=new QComboBox(parentFrame);
-  codecList->insertItem(preferences->getCodec()+" "+i18n("(Current)"));
+  codecList=new QComboBox(parentFrame);
+//  codecList->insertItem(preferences->getCodec()+" "+i18n("(Current)"));
 
   QStringList encodings=KGlobal::charsets()->descriptiveEncodingNames();
-
+  
   // from ksirc: remove utf16/ucs2 as it just doesn't work for IRC
   QStringList::Iterator iterator=encodings.begin();
   while(iterator!=encodings.end())
@@ -63,13 +64,24 @@ PrefsPageAppearance::PrefsPageAppearance(QFrame* newParent,Preferences* newPrefe
 
   codecList->insertStringList(encodings);
 
+  // find actual encoding and set combo box accordingly
+  QString actualEncoding="( "+preferences->getCodec()+" )";
+  for(unsigned int index=0;index<encodings.count();index++)
+  {
+    if(encodings[index].find(actualEncoding)!=-1)
+    {
+      codecList->setCurrentItem(index);
+      break;
+    }
+  }
+
   updateFonts();
 
   // Timestamp settings
   QHBox* timestampBox=new QHBox(parentFrame);
   timestampBox->setSpacing(spacingHint());
 
-  doTimestamping=new QCheckBox(i18n("Show Timestamps"),timestampBox,"show_timestamps_checkbox");
+  doTimestamping=new QCheckBox(i18n("Show timestamps"),timestampBox,"show_timestamps_checkbox");
 
   formatLabel=new QLabel(i18n("Format:"),timestampBox);
   formatLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
@@ -88,10 +100,10 @@ PrefsPageAppearance::PrefsPageAppearance(QFrame* newParent,Preferences* newPrefe
 
   QHBox* showButtonsBox=new QHBox(parentFrame);
 
-  showQuickButtons=new QCheckBox(i18n("Show Quick Buttons"),showButtonsBox,"show_quickbuttons_checkbox");
+  showQuickButtons=new QCheckBox(i18n("Show quick buttons"),showButtonsBox,"show_quickbuttons_checkbox");
   showQuickButtons->setChecked(preferences->getShowQuickButtons());
 
-  showModeButtons=new QCheckBox(i18n("Show Channel Mode Buttons"),showButtonsBox,"show_modebuttons_checkbox");
+  showModeButtons=new QCheckBox(i18n("Show channel mode buttons"),showButtonsBox,"show_modebuttons_checkbox");
   showModeButtons->setChecked(preferences->getShowModeButtons());
 
   useSpacingCheck=new QCheckBox(i18n("Use custom widget spacing"),parentFrame,"use_spacing_check");
@@ -115,6 +127,9 @@ PrefsPageAppearance::PrefsPageAppearance(QFrame* newParent,Preferences* newPrefe
   // Take care of ghosting / unghosting spacing widgets
   useSpacingChanged(preferences->getUseSpacing() ? 2 : 0);
 
+  QCheckBox* closeButtonsCheck=new QCheckBox(i18n("Show close widgets on tabs"),parentFrame,"tab_close_widgets_check");
+  closeButtonsCheck->setChecked(preferences->getCloseButtonsOnTabs());
+
   // Layout
   int row=0;
   appearanceLayout->addWidget(textFontLabel,row,0);
@@ -136,6 +151,8 @@ PrefsPageAppearance::PrefsPageAppearance(QFrame* newParent,Preferences* newPrefe
   row++;
   appearanceLayout->addMultiCellWidget(spacingMarginBox,row,row,0,2);
   row++;
+  appearanceLayout->addMultiCellWidget(closeButtonsCheck,row,row,0,2);
+  row++;
   appearanceLayout->setRowStretch(row,10);
   appearanceLayout->setColStretch(1,10);
 
@@ -144,7 +161,7 @@ PrefsPageAppearance::PrefsPageAppearance(QFrame* newParent,Preferences* newPrefe
   connect(textFontButton,SIGNAL (clicked()),this,SLOT (textFontClicked()) );
   connect(listFontButton,SIGNAL (clicked()),this,SLOT (listFontClicked()) );
 
-  connect(codecList,SIGNAL (highlighted(const QString&)),this,SLOT (encodingChanged(const QString&)));
+  connect(codecList,SIGNAL (activated(int)),this,SLOT (encodingChanged(int)));
 
   connect(doTimestamping,SIGNAL (stateChanged(int)),this,SLOT (timestampingChanged(int)) );
   connect(timestampFormat,SIGNAL(activated(const QString&)),this,SLOT(formatChanged(const QString&)));
@@ -155,6 +172,8 @@ PrefsPageAppearance::PrefsPageAppearance(QFrame* newParent,Preferences* newPrefe
   connect(useSpacingCheck,SIGNAL (stateChanged(int)),this,SLOT (useSpacingChanged(int)) );
   connect(spacing,SIGNAL (valueChanged(int)),this,SLOT (spacingChanged(int)));
   connect(margin,SIGNAL (valueChanged(int)),this,SLOT (marginChanged(int)));
+
+  connect(closeButtonsCheck,SIGNAL (stateChanged(int)),this,SLOT (showCloseButtonsChanged(int)) );
 }
 
 PrefsPageAppearance::~PrefsPageAppearance()
@@ -199,7 +218,6 @@ void PrefsPageAppearance::timestampingChanged(int state)
 
 void PrefsPageAppearance::formatChanged(const QString& newFormat)
 {
-  kdDebug() << newFormat << endl;
   preferences->setTimestampFormat(newFormat);
 }
 
@@ -213,12 +231,22 @@ void PrefsPageAppearance::showModeButtonsChanged(int state)
   preferences->setShowModeButtons(state==2);
 }
 
-void PrefsPageAppearance::encodingChanged(const QString& newEncoding)
+void PrefsPageAppearance::showCloseButtonsChanged(int state)
 {
-  if(newEncoding.startsWith("utf 16"))
-    preferences->setCodec(QString::null);
-  else
-    preferences->setCodec(KGlobal::charsets()->encodingForName(newEncoding));
+  preferences->setCloseButtonsOnTabs(state==2);
+}
+
+void PrefsPageAppearance::encodingChanged(int newEncodingIndex)
+{
+  if(newEncodingIndex)
+  {
+    QString newEncoding=codecList->text(newEncodingIndex);
+    
+    if(newEncoding.startsWith("utf 16"))
+      preferences->setCodec(QString::null);
+    else
+      preferences->setCodec(KGlobal::charsets()->encodingForName(newEncoding));
+  }
 }
 
 void PrefsPageAppearance::useSpacingChanged(int state)
