@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: server.cpp,v 1.52 2003/02/20 17:01:03 eisfuchs Exp $
+  $Id: server.cpp,v 1.73 2003/03/23 14:33:31 eisfuchs Exp $
 */
 
 #include <unistd.h>
@@ -35,16 +35,23 @@
 
 Server::Server(int id)
 {
+  setName("server");
   QStringList serverEntry=QStringList::split(',',KonversationApplication::preferences.getServerById(id),true);
   setIdentity(KonversationApplication::preferences.getIdentityByName(serverEntry[7]));
 
   tryNickNumber=0;
   checkTime=0;
+  reconnectCounter=0;
 
-  lastDccDir="";
+  resolver.setRecipient(this);
+  installEventFilter(this);
+
+  lastDccDir=QString::null;
 
   serverWindow=new ServerWindow(this);
-  setNickname(identity.getNickname(tryNickNumber));
+  setNickname(identity->getNickname(tryNickNumber));
+  bot=identity->getBot();
+  botPassword=identity->getPassword();
   serverWindow->setIdentity(getIdentity());
   serverWindow->show();
 
@@ -52,7 +59,9 @@ Server::Server(int id)
   serverPort=serverEntry[2].toInt();
   serverKey=serverEntry[3];
 
-  if(serverEntry[4] && serverEntry[4]!="")
+  serverSocket.setAddress(serverName,serverPort);
+
+  if(serverEntry[4] && !serverEntry[4].isEmpty())
   {
     setAutoJoin(true);
     setAutoJoinChannel(serverEntry[4]);
@@ -63,7 +72,6 @@ Server::Server(int id)
   autoRejoin=KonversationApplication::preferences.getAutoRejoin();
   autoReconnect=KonversationApplication::preferences.getAutoReconnect();
 
-  serverSocket=0;
   connectToIRCServer();
 
   // don't delete items when they are removed
@@ -74,6 +82,8 @@ Server::Server(int id)
   inputFilter.setServer(this);
   outputFilter.setIdentity(identity);
 
+  notifyTimer.setName("notifyTimer");
+  incomingTimer.setName("incomingTimer");
   incomingTimer.start(10);
 
   connect(&incomingTimer,SIGNAL(timeout()),
@@ -81,9 +91,11 @@ Server::Server(int id)
 
   connect(&outputFilter,SIGNAL (openQuery(const QString&,const QString&)),
                    this,SLOT   (addQuery(const QString&,const QString&)) );
-  connect(&outputFilter,SIGNAL (requestDccSend(QString)),
-                   this,SLOT   (requestDccSend(QString)) );
-
+  connect(&outputFilter,SIGNAL (requestDccSend()),
+                   this,SLOT   (requestDccSend()) );
+  connect(&outputFilter,SIGNAL (requestDccSend(const QString &)),
+                   this,SLOT   (requestDccSend(const QString &)) );
+  
   connect(&notifyTimer,SIGNAL(timeout()),
                   this,SLOT  (notifyTimeout()) );
   connect(&notifyCheckTimer,SIGNAL(timeout()),
@@ -91,104 +103,146 @@ Server::Server(int id)
 
   connect(&inputFilter,SIGNAL(welcome()),
                   this,SLOT  (connectionEstablished()) );
-  connect(&inputFilter,SIGNAL(notifyResponse(QString)),
-                  this,SLOT  (notifyResponse(QString)) );
-  connect(&inputFilter,SIGNAL(addDccGet(QString,QStringList)),
-                  this,SLOT  (addDccGet(QString,QStringList)) );
-  connect(&inputFilter,SIGNAL(resumeDccGetTransfer(QString,QStringList)),
-                  this,SLOT  (resumeDccGetTransfer(QString,QStringList)) );
-  connect(&inputFilter,SIGNAL(resumeDccSendTransfer(QString,QStringList)),
-                  this,SLOT  (resumeDccSendTransfer(QString,QStringList)) );
+  connect(&inputFilter,SIGNAL(notifyResponse(const QString &)),
+                  this,SLOT  (notifyResponse(const QString &)) );
+  connect(&inputFilter,SIGNAL(addDccGet(const QString &, const QStringList &)),
+                  this,SLOT  (addDccGet(const QString &, const QStringList &)) );
+  connect(&inputFilter,SIGNAL(resumeDccGetTransfer(const QString &, const QStringList &)),
+                  this,SLOT  (resumeDccGetTransfer(const QString &, const QStringList &)) );
+  connect(&inputFilter,SIGNAL(resumeDccSendTransfer(const QString &, const QStringList &)),
+                  this,SLOT  (resumeDccSendTransfer(const QString &, const QStringList &)) );
 
   connect(this,SIGNAL(serverLag(int)),serverWindow,SLOT(updateLag(int)) );
   connect(this,SIGNAL(tooLongLag(int)),serverWindow,SLOT(tooLongLag(int)) );
   connect(this,SIGNAL(resetLag()),serverWindow,SLOT(resetLag()) );
   connect(this,SIGNAL(addDccPanel()),serverWindow,SLOT(addDccPanel()) );
   connect(this,SIGNAL(closeDccPanel()),serverWindow,SLOT(closeDccPanel()) );
+
+  connect(&serverSocket,SIGNAL (connectionSuccess())  ,this,SLOT (ircServerConnectionSuccess()) );
+  connect(&serverSocket,SIGNAL (connectionFailed(int)),this,SLOT (broken(int)) );
+  connect(&serverSocket,SIGNAL (readyRead()),this,SLOT (incoming()) );
+  connect(&serverSocket,SIGNAL (readyWrite()),this,SLOT (send()) );
+  connect(&serverSocket,SIGNAL (closed(int)),this,SLOT (broken(int)) );
 }
 
 Server::~Server()
 {
   kdDebug() << "Server::~Server()" << endl;
 
-  if(serverSocket)
-  {
-    // Make sure no signals get sent to a soon to be dying Server Window
-    serverSocket->blockSignals(true);
-    // Send out the last messages (usually the /QUIT)
-    serverSocket->enableWrite(true);
-    send();
-    delete serverSocket;
-  }
+  // Make sure no signals get sent to a soon to be dying Server Window
+  serverSocket.blockSignals(true);
+  // Send out the last messages (usually the /QUIT)
+  serverSocket.enableWrite(true);
+  send();
 
+  // notify KonversationApplication that this server is gone
+  emit deleted(this);
+  
   delete serverWindow;
 }
 
-QString Server::getServerName()
-{
-  return serverName;
-}
-
-int Server::getPort()
-{
-  return serverPort;
-}
-
-bool Server::getAutoJoin()
-{
-  return autoJoin;
-}
+QString Server::getServerName() { return serverName; }
+int Server::getPort() { return serverPort; }
 
+bool Server::getAutoJoin() { return autoJoin; }
 void Server::setAutoJoin(bool on) { autoJoin=on; }
-void Server::setAutoJoinChannel(QString channel) { autoJoinChannel=channel; }
-void Server::setAutoJoinChannelKey(QString key) { autoJoinChannelKey=key; }
+
+QString Server::getAutoJoinChannel() { return autoJoinChannel; }
+void Server::setAutoJoinChannel(const QString &channel) { autoJoinChannel=channel; }
+
+QString Server::getAutoJoinChannelKey() { return autoJoinChannelKey; }
+void Server::setAutoJoinChannelKey(const QString &key) { autoJoinChannelKey=key; }
+
+bool Server::isConnected() { return serverSocket.socketStatus()==KExtendedSocket::connected; }
 
 void Server::connectToIRCServer()
 {
   deliberateQuit=false;
+  serverSocket.blockSignals(false);
   // Are we (still) connected (yet)?
-  if(serverSocket)
+  if(isConnected())
   {
     // just join our autojoin-channel if desired
-    if(getAutoJoin()) queue(getAutoJoinCommand());
+    if (getAutoJoin()) queue(getAutoJoinCommand());
     // TODO: move autojoin here and use signals / slots
   }
   else
   {
     // (re)connect. Autojoin will be done by the input filter
-    serverWindow->appendToStatus(i18n("Info"),i18n("Connecting ..."));
+    serverWindow->appendToStatus(i18n("Info"),i18n("Looking for server %1 ...").arg(serverSocket.host()));
 
-    serverSocket=new IRCServerSocket(getServerName(),getPort());
-    serverSocket->connect();
+    // QDns is broken, so don't use async lookup, use own threaded class instead
+    resolver.setSocket(&serverSocket);
+    resolver.start();
+  }
+}
 
-    if(serverSocket->fd()<=-1)
+bool Server::eventFilter(QObject* parent,QEvent* event)
+{
+  if(event->type()==QEvent::User)
+  {
+    lookupFinished();
+    return true;
+  }
+  return QObject::eventFilter(parent,event);
+}
+
+void Server::lookupFinished()
+{
+  serverWindow->appendToStatus(i18n("Info"),i18n("Server found, connecting ..."));
+  serverSocket.startAsyncConnect();
+}
+
+void Server::ircServerConnectionSuccess()
+{
+  reconnectCounter=0;
+
+  connect(this,SIGNAL (nicknameChanged(const QString&)),serverWindow,SLOT (setNickname(const QString&)) );
+
+  serverWindow->appendToStatus(i18n("Info"),i18n("Connected! Logging in ..."));
+
+  QString connectString="USER " +
+                        identity->getIdent() +
+                        " 8 * :" +  // 8 = +i; 4 = +w
+                        identity->getRealName();
+
+  if (serverKey) queue("PASS "+serverKey);
+  queue("NICK "+getNickname());
+  queue(connectString);
+
+  emit nicknameChanged(getNickname());
+
+  serverSocket.enableRead(true);
+}
+
+void Server::broken(int state)
+{
+  serverSocket.enableRead(false);
+  serverSocket.enableWrite(false);
+  serverSocket.blockSignals(true);
+
+  kdDebug() << "Connection broken (Socket fd " << serverSocket.fd() << ") " << state << "!" << endl;
+
+  // TODO: Close all queries and channels!
+  //       Or at least make sure that all gets reconnected properly
+
+  if(autoReconnect && !getDeliberateQuit())
+  {
+    serverWindow->appendToStatus(i18n("Error"),i18n("Connection to Server %1 lost. Trying to reconnect.").arg(serverName));
+
+    // TODO: Make retry counter configurable
+    if(++reconnectCounter==10)
     {
-      broken(0);
+      serverWindow->appendToStatus(i18n("Error"),i18n("Connection to Server %1 failed.").arg(serverName));
+      reconnectCounter=0;
     }
     else
-    {
-      connect(serverSocket,SIGNAL (readyRead()),this,SLOT (incoming()) );
-      connect(serverSocket,SIGNAL (readyWrite()),this,SLOT (send()) );
-      connect(serverSocket,SIGNAL (closed(int)),this,SLOT (broken(int)) );
-//      connect(serverSocket,SIGNAL (connectionFailed(int)),this,SLOT (broken(int)) );
-
-      connect(this,SIGNAL (nicknameChanged(const QString&)),serverWindow,SLOT (setNickname(const QString&)) );
-
-      serverWindow->appendToStatus(i18n("Info"),i18n("Connected! Logging in ..."));
-
-      QString connectString="USER " +
-                            identity.getIdent() +
-                            " 8 * :" +  // 8 = +i; 4 = +w
-                            identity.getRealName();
-
-      if(serverKey) queue("PASS "+serverKey);
-      queue("NICK "+getNickname());
-      queue(connectString);
-
-      emit nicknameChanged(getNickname());
-
-      serverSocket->enableRead(true);
-    }
+      // TODO: Make timeout configurable
+      QTimer::singleShot(5000,this,SLOT(connectToIRCServer()));
+  }
+  else
+  {
+    serverWindow->appendToStatus(i18n("Error"),i18n("Connection to Server %1 closed.").arg(serverName));
   }
 }
 
@@ -197,9 +251,12 @@ void Server::connectionEstablished()
 {
   // get first notify very early
   startNotifyTimer(1000);
+  // register with services
+  if(!botPassword.isEmpty() && !bot.isEmpty())
+    queue("PRIVMSG "+bot+" :identify "+botPassword);
 }
 
-void Server::notifyResponse(QString nicksOnline)
+void Server::notifyResponse(const QString& nicksOnline)
 {
   // We received a 303 or "PONG :LAG" notify message, so calculate server lag
   int lag=notifySent.elapsed();
@@ -245,6 +302,8 @@ void Server::notifyResponse(QString nicksOnline)
 
 void Server::startNotifyTimer(int msec)
 {
+  // make sure the timer gets started properly in case we have reconnected
+  notifyTimer.stop();
   if(msec==0) msec=KonversationApplication::preferences.getNotifyDelay()*1000; // msec!
   // start the timer in one shot mode
   notifyTimer.start(msec,true);
@@ -268,7 +327,7 @@ void Server::notifyTimeout()
   {
     // But only if there actually are nicks in the notify list
     QString list=KonversationApplication::preferences.getNotifyString();
-    if(list!="")
+    if(!list.isEmpty())
     {
       queue("ISON "+list);
       // remember that we already sent out ISON
@@ -285,7 +344,7 @@ void Server::notifyTimeout()
 void Server::notifyCheckTimeout()
 {
   checkTime+=500;
-  if(serverSocket) emit tooLongLag(checkTime);
+  if(isConnected()) emit tooLongLag(checkTime);
 }
 
 QString Server::getAutoJoinCommand()
@@ -305,8 +364,8 @@ QString Server::getNextNickname()
   if(tryNickNumber!=4)
   {
     tryNickNumber++;
-    if(tryNickNumber==4) newNick=getNickname()+"_";
-    else newNick=identity.getNickname(tryNickNumber);
+    if (tryNickNumber==4) newNick=getNickname()+"_";
+    else newNick=identity->getNickname(tryNickNumber);
   }
   return newNick;
 }
@@ -322,18 +381,17 @@ void Server::processIncomingData()
 
     inputBuffer=inputBuffer.mid(pos+1);
 
-    kdDebug() << line << endl;
-
+    getServerWindow()->appendToRaw(line);
     inputFilter.parseLine(line);
   }
 }
 
 void Server::incoming()
 {
-  char buffer[513];
+  char buffer[BUFFER_LEN];
   int len=0;
 
-  len=read(serverSocket->fd(),buffer,512);
+  len=read(serverSocket.fd(),buffer,BUFFER_LEN-1);
 
   buffer[len]=0;
 
@@ -342,41 +400,64 @@ void Server::incoming()
   if(len==0) broken(0);
 }
 
-void Server::queue(const QString& buffer)
+void Server::queue(const QString &buffer)
 {
   // Only queue lines if we are connected
-  if(serverSocket && buffer.length())
+  if(isConnected() && buffer.length())
   {
-    kdDebug() << "Q: " << buffer << endl;
-
+    getServerWindow()->appendToRaw(buffer);
     outputBuffer+=buffer;
     outputBuffer+="\n";
 
-    serverSocket->enableWrite(true);
+    serverSocket.enableWrite(true);
   }
 }
 
 void Server::send()
 {
   // Check if we are still online
-  if(serverSocket)
+  if(isConnected())
   {
-//    kdDebug() << "-> " << outputBuffer << endl;
     // To make lag calculation more precise, we reset the timer here
     if(outputBuffer.startsWith("ISON") ||
        outputBuffer.startsWith("PING LAG")) notifySent.start();
+    
     // Don't reconnect if we WANT to quit
     else if(outputBuffer.startsWith("QUIT")) setDeliberateQuit(true);
+    
     // TODO: Implement Flood-Protection here
-//    write(serverSocket->fd(),outputBuffer.latin1(),outputBuffer.length());
-    write(serverSocket->fd(),outputBuffer,outputBuffer.length());
-    serverSocket->enableWrite(false);
+    write(serverSocket.fd(),outputBuffer,outputBuffer.length());
+    serverSocket.enableWrite(false);
   }
 
-  outputBuffer="";
+  outputBuffer=QString::null;
 }
 
-void Server::ctcpReply(QString& receiver,const QString& text)
+void Server::dcopSay(const QString& target,const QString& command)
+{
+  if(isAChannel(target))
+  {
+    Channel* channel=getChannelByName(target);
+    if(channel) channel->sendChannelText(command);
+  }
+  else
+  {
+    Query* query=getQueryByName(target);
+    if(query==0)
+    {
+      addQuery(target,QString::null);
+      query=getQueryByName(target);
+    }
+    if(query) query->sendQueryText(command);
+  }
+}
+
+void Server::dcopInfo(const QString& string)
+{
+  appendStatusMessage(i18n("DCOP"),string);
+}
+
+void Server::ctcpReply(const QString &receiver,const QString &text)
 {
   queue("NOTICE "+receiver+" :"+'\x01'+text+'\x01');
 }
@@ -391,30 +472,7 @@ void Server::setDeliberateQuit(bool on)
   deliberateQuit=on;
 }
 
-void Server::broken(int state)
-{
-  kdDebug() << "Connection broken (Socket fd " << serverSocket->fd() << ") " << state << "!" << endl;
-
-  serverWindow->appendToStatus(i18n("Error"),i18n("Connection to Server %1 lost.").arg(serverName));
-  // TODO: Close all queries and channels!
-  //       Or at least make sure that all gets reconnected properly
-  disconnect(serverSocket,0,0,0);
-  delete serverSocket;
-  serverSocket=0;
-  kdDebug() << "Socket deleted" << endl;
-
-  if(autoReconnect && !getDeliberateQuit())
-  {
-    serverWindow->appendToStatus(i18n("Error"),i18n("Connection to Server %1 lost. Trying to reconnect.").arg(serverName));
-    connectToIRCServer();
-  }
-  else
-  {
-    serverWindow->appendToStatus(i18n("Error"),i18n("Connection to Server %1 closed.").arg(serverName));
-  }
-}
-
-void Server::addQuery(const QString& nickname,const QString& hostmask)
+void Server::addQuery(const QString &nickname,const QString &hostmask)
 {
   // Only create new query object if there isn't already one with the same name
   Query* query=getQueryByName(nickname);
@@ -429,27 +487,34 @@ void Server::addQuery(const QString& nickname,const QString& hostmask)
 
     connect(query,SIGNAL (newText(QWidget*)),serverWindow,SLOT (newText(QWidget*)) );
     connect(query,SIGNAL (closed(Query*)),this,SLOT (removeQuery(Query*)) );
+    connect(query,SIGNAL (sendFile(const QString&)),this,SLOT (requestDccSend(const QString &)) );
     // Append query to internal list
     queryList.append(query);
   }
   // Always set hostmask
-  query->setHostmask(hostmask);
+  if(query) query->setHostmask(hostmask);
 }
 
-void Server::closeQuery(const QString& name)
+void Server::closeQuery(const QString &name)
 {
   Query* query=getQueryByName(name);
   removeQuery(query);
 }
 
-void Server::closeChannel(const QString& name)
+void Server::closeChannel(const QString &name)
 {
   outputFilter.parse(getNickname(),KonversationApplication::preferences.getCommandChar()+"PART",name);
   queue(outputFilter.getServerOutput());
 }
 
-void Server::requestDccSend(QString recipient)
+void Server::requestDccSend()
 {
+  requestDccSend(QString::null);
+}
+
+void Server::requestDccSend(const QString &a_recipient)
+{
+  QString recipient(a_recipient);
   // if we don't have a recipient yet, let the user select one
   if(!recipient)
   {
@@ -480,7 +545,7 @@ void Server::requestDccSend(QString recipient)
     recipient=DccRecipientDialog::getNickname(getServerWindow(),nickList);
   }
   // do we have a recipient *now*?
-  if(recipient && recipient!="")
+  if(recipient && !recipient.isEmpty())
   {
     QString fileName=KFileDialog::getOpenFileName(
                                                    lastDccDir,
@@ -488,7 +553,7 @@ void Server::requestDccSend(QString recipient)
                                                    getServerWindow(),
                                                    i18n("Select file to send to %1").arg(recipient)
                                                  );
-    if(fileName!="")
+    if(!fileName.isEmpty())
     {
       QFileInfo fileInfo(fileName);
 
@@ -502,12 +567,12 @@ void Server::requestDccSend(QString recipient)
   }
 }
 
-void Server::addDccSend(QString recipient,QString fileName)
+void Server::addDccSend(const QString &recipient,const QString &fileName)
 {
   emit addDccPanel();
 
   // Get our own IP address. Don't laugh! This works!
-  QString ip=KExtendedSocket::localAddress(serverSocket->fd())->pretty();
+  QString ip=KExtendedSocket::localAddress(serverSocket.fd())->pretty();
   ip=ip.section('-',0,0);
 
   // We already checked that the file exists in output filter / requestDccSend() resp.
@@ -525,13 +590,13 @@ void Server::addDccSend(QString recipient,QString fileName)
                   ip,                  // ip
                   0);                  // port (will be set by DccTransfer)
 
-  connect(newDcc,SIGNAL (send(QString,QString,QString,QString,unsigned long)),
-    this,SLOT (dccSendRequest(QString,QString,QString,QString,unsigned long)) );
-  connect(newDcc,SIGNAL (dccSendDone(QString)),this,SLOT (dccSendDone(QString)) );
+  connect(newDcc,SIGNAL (send(const QString&,const QString&,const QString&,const QString&,unsigned long)),
+    this,SLOT (dccSendRequest(const QString&,const QString&,const QString&,const QString&,unsigned long)) );
+  connect(newDcc,SIGNAL (dccSendDone(const QString&)),this,SLOT (dccSendDone(const QString&)) );
   newDcc->startSend();
 }
 
-void Server::addDccGet(QString sourceNick,QStringList dccArguments)
+void Server::addDccGet(const QString &sourceNick, const QStringList &dccArguments)
 {
   emit addDccPanel();
 
@@ -543,7 +608,7 @@ void Server::addDccGet(QString sourceNick,QStringList dccArguments)
                       QString("%1 offers the file \"%2\" (%3 bytes) for download (%4:%5).")
                               .arg(sourceNick)               // name
                               .arg(dccArguments[0])          // file
-                              .arg((dccArguments[3]=="") ? i18n("unknown") : dccArguments[3] )  // size
+                              .arg((dccArguments[3].isEmpty()) ? i18n("unknown") : dccArguments[3] )  // size
                               .arg(ip.toString())            // ip
                               .arg(dccArguments[2])          // port
                              );
@@ -557,8 +622,10 @@ void Server::addDccGet(QString sourceNick,QStringList dccArguments)
                   ip.toString(),       // ip
                   dccArguments[2]);    // port
 
-  connect(newDcc,SIGNAL (resumeGet(QString,QString,QString,int)),this,SLOT (dccResumeGetRequest(QString,QString,QString,int)) );
-  connect(newDcc,SIGNAL (dccGetDone(QString)),this,SLOT (dccGetDone(QString)) );
+  connect(newDcc,SIGNAL (resumeGet(const QString&,const QString&,const QString&,int)),this,
+         SLOT (dccResumeGetRequest(const QString&,const QString&,const QString&,int)) );
+  connect(newDcc,SIGNAL (dccGetDone(const QString&)),
+              this,SLOT (dccGetDone(const QString&)) );
 
   if(KonversationApplication::preferences.getDccAutoGet()) newDcc->startGet();
 }
@@ -573,7 +640,7 @@ void Server::requestCloseDccPanel()
   emit closeDccPanel();
 }
 
-void Server::dccSendRequest(QString partner,QString fileName,QString address,QString port,unsigned long size)
+void Server::dccSendRequest(const QString &partner, const QString &fileName, const QString &address, const QString &port, unsigned long size)
 {
   kdDebug() << "Server::dccSendRequest()" << endl;
   outputFilter.sendRequest(partner,fileName,address,port,size);
@@ -581,7 +648,7 @@ void Server::dccSendRequest(QString partner,QString fileName,QString address,QSt
   appendStatusMessage(outputFilter.getType(),outputFilter.getOutput());
 }
 
-void Server::dccResumeGetRequest(QString sender,QString fileName,QString port,int startAt)
+void Server::dccResumeGetRequest(const QString &sender, const QString &fileName, const QString &port, int startAt)
 {
   kdDebug() << "Server::dccResumeGetRequest()" << endl;
   outputFilter.resumeRequest(sender,fileName,port,startAt);
@@ -589,7 +656,7 @@ void Server::dccResumeGetRequest(QString sender,QString fileName,QString port,in
   appendStatusMessage(outputFilter.getType(),outputFilter.getOutput());
 }
 
-void Server::resumeDccGetTransfer(QString sourceNick,QStringList dccArguments)
+void Server::resumeDccGetTransfer(const QString &sourceNick, const QStringList &dccArguments)
 {
   // Check if there actually is a transfer going on on that port
   DccTransfer* dccTransfer=serverWindow->getDccPanel()->getTransferByPort(dccArguments[1],DccTransfer::ResumeGet);
@@ -612,7 +679,7 @@ void Server::resumeDccGetTransfer(QString sourceNick,QStringList dccArguments)
   }
 }
 
-void Server::resumeDccSendTransfer(QString recipient,QStringList dccArguments)
+void Server::resumeDccSendTransfer(const QString &recipient, const QStringList &dccArguments)
 {
   // Check if there actually is a transfer going on on that port
   DccTransfer* dccTransfer=serverWindow->getDccPanel()->getTransferByPort(dccArguments[1],DccTransfer::Send);
@@ -638,12 +705,12 @@ void Server::resumeDccSendTransfer(QString recipient,QStringList dccArguments)
   }
 }
 
-void Server::dccGetDone(QString fileName)
+void Server::dccGetDone(const QString &fileName)
 {
   appendStatusMessage(i18n("DCC"),i18n("DCC download of file \"%1\" finished.").arg(fileName));
 }
 
-void Server::dccSendDone(QString fileName)
+void Server::dccSendDone(const QString &fileName)
 {
   appendStatusMessage(i18n("DCC"),i18n("DCC upload of file \"%1\" finished.").arg(fileName));
 }
@@ -682,12 +749,8 @@ void Server::removeQuery(Query* query)
   delete query;
 }
 
-void Server::joinChannel(QString& name,QString& hostmask,QString& key)
+void Server::joinChannel(const QString &name, const QString &hostmask, const QString &/*key*/)
 {
-  // if(mode==singleWindows)
-  //   Channel* channel=new Channel(this,name,0);
-  // else
-
   // Make sure to delete stale Channel on rejoin.
   // FIXME: Hm ... Do we really have to? Wouldn't it be enough to just
   // keep the channel and set channel->setServer(server)?
@@ -704,15 +767,15 @@ void Server::joinChannel(QString& name,QString& hostmask,QString& key)
   channel->setIdentity(getIdentity());
   channel->setName(name);
   channel->setNickname(getNickname());
-//  channel->setKey(key);
+  //channel->setKey(key);
 
   serverWindow->addView(channel,1,name);
   channel->joinNickname(getNickname(),hostmask);
-//  serverWindow->showView(channel->getChannelPane());
-  // endif
+
   channelList.append(channel);
   connect(channel,SIGNAL (newText(QWidget*)),serverWindow,SLOT (newText(QWidget*)) );
   connect(channel,SIGNAL (prefsChanged()),serverWindow,SLOT (channelPrefsChanged()) );
+  connect(channel,SIGNAL (sendFile()),this,SLOT (requestDccSend()) );
 }
 
 void Server::removeChannel(Channel* channel)
@@ -720,13 +783,13 @@ void Server::removeChannel(Channel* channel)
   channelList.removeRef(channel);
 }
 
-void Server::updateChannelMode(QString& nick,QString& channelName,char mode,bool plus,QString& parameter)
+void Server::updateChannelMode(const QString &nick, const QString &channelName, char mode, bool plus, const QString &parameter)
 {
   Channel* channel=getChannelByName(channelName);
   if(channel) channel->updateMode(nick,mode,plus,parameter);
 }
 
-void Server::updateChannelModeWidgets(QString& channelName,char mode,QString& parameter)
+void Server::updateChannelModeWidgets(const QString &channelName, char mode, const QString &parameter)
 {
   Channel* channel=getChannelByName(channelName);
   if(channel) channel->updateModeWidgets(mode,true,parameter);
@@ -762,7 +825,11 @@ void Server::updateFonts()
   }
 
   // TODO: To be revised
-  if(serverWindow) serverWindow->updateFonts();
+  if(serverWindow)
+  {
+    serverWindow->updateFonts();
+    emit repaintTabs();
+  }
 }
 
 // TODO: Maybe use a Signal / Slot mechanism for these things?
@@ -821,19 +888,19 @@ Query* Server::getQueryByName(const char* name)
   return 0;
 }
 
-void Server::addNickToChannel(QString& channelName,QString& nickname,QString& hostmask,bool op,bool voice)
+void Server::addNickToChannel(const QString &channelName, const QString &nickname, const QString &hostmask, bool op, bool voice)
 {
   Channel* outChannel=getChannelByName(channelName);
   if(outChannel) outChannel->addNickname(nickname,hostmask,op,voice);
 }
 
-void Server::nickJoinsChannel(QString& channelName,QString& nickname,QString& hostmask)
+void Server::nickJoinsChannel(const QString &channelName, const QString &nickname, const QString &hostmask)
 {
   Channel* outChannel=getChannelByName(channelName);
   if(outChannel) outChannel->joinNickname(nickname,hostmask);
 }
 
-void Server::addHostmaskToNick(QString& sourceNick,QString& sourceHostmask)
+void Server::addHostmaskToNick(const QString &sourceNick, const QString &sourceHostmask)
 {
   Channel* channel=channelList.first();
 
@@ -848,7 +915,7 @@ void Server::addHostmaskToNick(QString& sourceNick,QString& sourceHostmask)
   if(query) query->setHostmask(sourceHostmask);
 }
 
-void Server::removeNickFromChannel(QString& channelName,QString& nickname,QString& reason,bool quit)
+void Server::removeNickFromChannel(const QString &channelName, const QString &nickname, const QString &reason, bool quit)
 {
   Channel* outChannel=getChannelByName(channelName);
   if(outChannel)
@@ -857,7 +924,7 @@ void Server::removeNickFromChannel(QString& channelName,QString& nickname,QStrin
   }
 }
 
-void Server::nickWasKickedFromChannel(QString& channelName,QString& nickname,QString& kicker,QString& reason)
+void Server::nickWasKickedFromChannel(const QString &channelName, const QString &nickname, const QString &kicker, const QString &reason)
 {
   Channel* outChannel=getChannelByName(channelName);
   if(outChannel)
@@ -866,7 +933,7 @@ void Server::nickWasKickedFromChannel(QString& channelName,QString& nickname,QSt
   }
 }
 
-void Server::removeNickFromServer(QString& nickname,QString& reason)
+void Server::removeNickFromServer(const QString &nickname,const QString &reason)
 {
   Channel* channel=channelList.first();
   while(channel)
@@ -876,7 +943,7 @@ void Server::removeNickFromServer(QString& nickname,QString& reason)
   }
 }
 
-void Server::renameNick(QString& nickname,QString& newNick)
+void Server::renameNick(const QString &nickname, const QString &newNick)
 {
   // Rename the nick in every channel they are in
   Channel* channel=channelList.first();
@@ -957,13 +1024,13 @@ void Server::appendStatusMessage(const char* type,const char* message)
   serverWindow->appendToFrontmost(type,message);
 }
 
-void Server::setNickname(const QString& newNickname)
+void Server::setNickname(const QString &newNickname)
 {
   nickname=newNickname;
   serverWindow->setNickname(newNickname);
 }
 
-void Server::setChannelTopic(QString& channel,QString& newTopic)
+void Server::setChannelTopic(const QString &channel, const QString &newTopic)
 {
   Channel* outChannel=getChannelByName(channel);
   if(outChannel)
@@ -974,7 +1041,7 @@ void Server::setChannelTopic(QString& channel,QString& newTopic)
   }
 }
 
-void Server::setChannelTopic(QString& nickname,QString& channel,QString& newTopic) // Overloaded
+void Server::setChannelTopic(const QString& nickname, const QString &channel, const QString &newTopic) // Overloaded
 {
   Channel* outChannel=getChannelByName(channel);
   if(outChannel)
@@ -985,26 +1052,26 @@ void Server::setChannelTopic(QString& nickname,QString& channel,QString& newTopi
   }
 }
 
-bool Server::isNickname(QString& compare)
+bool Server::isNickname(const QString &compare)
 {
   return (nickname==compare);
 }
 
-QString& Server::getNickname()
+QString Server::getNickname()
 {
   return nickname;
 }
 
-QString Server::parseWildcards(const QString& toParse,const QString& nickname,const QString& channelName,const QString& channelKey,const QString& nick,const QString& queryName,const QString& parameter)
+QString Server::parseWildcards(const QString &toParse, const QString &nickname, const QString &channelName, const QString &channelKey, const QString &nick, const QString &queryName, const QString &parameter)
 {
   return parseWildcards(toParse,nickname,channelName,channelKey,QStringList::split(' ',nick),queryName,parameter);
 }
 
-QString Server::parseWildcards(const QString& toParse,const QString& nickname,const QString& channelName,const QString& channelKey,const QStringList& nickList,const QString& queryName,const QString& parameter)
+QString Server::parseWildcards(const QString &toParse, const QString &nickname, const QString &channelName, const QString &channelKey, const QStringList &nickList, const QString &queryName, const QString &/*parameter*/)
 {
-  // TODO: parameter handling. this line is only to suppress a compiler warning
+  // TODO: parameter handling.
   //       since parameters are not functional yet
-  parameter.lower();
+
   // cut button name from definition
   QString out(toParse.mid(toParse.find(',')+1));
   // define default separator and regular expression for definition
@@ -1021,7 +1088,7 @@ QString Server::parseWildcards(const QString& toParse,const QString& nickname,co
     // copy out all text to the next "%" as new separator
     separator=out.mid(pos,out.find("%",pos+1)-pos);
     // remove separator definition from string
-    out.replace(separatorRegExp,"");
+    out.replace(separatorRegExp, QString::null);
   }
 
   kdDebug() << "Replacing placeholders in: " << out << endl;
@@ -1041,12 +1108,12 @@ QString Server::parseWildcards(const QString& toParse,const QString& nickname,co
   return out;
 }
 
-void Server::setIrcName(QString newIrcName)
+void Server::setIrcName(const QString &newIrcName)
 {
   ircName=newIrcName;
 }
 
-const QString& Server::getIrcName()
+QString Server::getIrcName()
 {
   return ircName;
 }
@@ -1071,7 +1138,7 @@ void Server::away()
   isAway=true;
 }
 
-void Server::sendToAllChannels(const QString& text)
+void Server::sendToAllChannels(const QString &text)
 {
   // Send a message to all channels we are in
   Channel* channel=channelList.first();
@@ -1083,12 +1150,39 @@ void Server::sendToAllChannels(const QString& text)
   }
 }
 
+void Server::scriptNotFound(const QString& name)
+{
+  appendStatusMessage(i18n("DCOP"),i18n("Error: Could not find script \"%1\".").arg(name));
+}
+
+void Server::scriptExecutionError(const QString& name)
+{
+  appendStatusMessage(i18n("DCOP"),i18n("Error: Could not execute script \"%1\". Check file permissions.").arg(name));
+}
+
 void Server::unAway()
 {
   isAway=false;
 }
 
-void Server::setIdentity(Identity newIdentity) { identity=newIdentity; }
-const Identity& Server::getIdentity() { return identity; }
+bool Server::isAChannel(const QString &check)
+{
+  QChar initial=check.at(0);
+
+  return (initial=='#' || initial=='&' || initial=='+' || initial=='!');
+}
+
+void Server::addRawLog()
+{
+  getServerWindow()->addRawLog();
+}
+
+void Server::closeRawLog()
+{
+  getServerWindow()->closeRawLog();
+}
+
+void Server::setIdentity(const Identity *newIdentity) { identity=newIdentity; }
+const Identity *Server::getIdentity() { return identity; }
 
 #include "server.moc"
