@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: serverentry.cpp,v 1.8 2003/02/10 16:39:50 eisfuchs Exp $
+  $Id: serverentry.cpp,v 1.9 2003/03/07 14:43:25 eisfuchs Exp $
 */
 
 #include <qstringlist.h>
@@ -31,7 +31,7 @@ ServerEntry::ServerEntry(const QString newDefinition)
   while(properties.count()<8)
   {
     definition=definition+",";
-    properties.append("");
+    properties.append(QString::null);
   }
 }
 
