@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: serverentry.h,v 1.5 2003/01/28 12:20:49 eisfuchs Exp $
+  $Id: serverentry.h,v 1.6 2003/02/10 16:39:50 eisfuchs Exp $
 */
 
 #ifndef SERVERENTRY_H
@@ -33,10 +33,11 @@ class ServerEntry
     QString getChannelName();
     QString getChannelKey();
     bool getAutoConnect();
-    QString getDefinition() { return definition; };
+    QString getIdentity();
+    QString getDefinition();
 
-    void setDefinition(const QString& newDefinition) { definition=newDefinition; };
-    int getId() { return id; };
+    void setDefinition(const QString& newDefinition);
+    int getId();
     void updateProperty(int property,const QString& value);
 
   protected:
