@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: serverwindow.cpp,v 1.44 2003/02/20 17:01:06 eisfuchs Exp $
+  $Id: serverwindow.cpp,v 1.57 2003/03/23 14:33:31 eisfuchs Exp $
 */
 
 #include <qdir.h>
@@ -21,6 +21,8 @@
 #include <kdialog.h>
 #include <kaccel.h>
 #include <kmessagebox.h>
+#include <kstatusbar.h>
+#include <kmenubar.h>
 
 #include "serverwindow.h"
 #include "konversationapplication.h"
@@ -37,15 +39,19 @@ ServerWindow::ServerWindow(Server* newServer) : KMainWindow()
   nicksOnlineWindow=0;
   dccPanel=0;
   dccPanelOpen=false;
+  rawLog=0;
 
   setServer(newServer);
 
   windowContainer=new LedTabWidget(this,"server_window_tab_widget");
   windowContainer->setTabPosition(QTabWidget::Bottom);
 
+  connect(getServer(),SIGNAL(repaintTabs()),getWindowContainer(),SLOT(updateTabs()) );
+
 /*  KAction* quitAction= */ KStdAction::quit(this,SLOT(quitProgram()),actionCollection()); /* file_quit */
   showToolBarAction=KStdAction::showToolbar(this,SLOT(showToolbar()),actionCollection()); /* options_show_toolbar */
   showStatusBarAction=KStdAction::showStatusbar(this,SLOT(showStatusbar()),actionCollection()); /* options_show_statusbar */
+  showMenuBarAction=KStdAction::showMenubar(this,SLOT(showMenubar()),actionCollection()); /* options_show_menubar */
 /*  KAction* prefsAction= */ KStdAction::preferences(this,SLOT(openPreferences()),actionCollection()); /* options_configure */
 /*  KAction* open_quickbuttons_action= */ new KAction(i18n("Buttons"),0,0,this,SLOT (openButtons()),actionCollection(),"open_buttons_window");
 /*  KAction* open_hilight_action=      */ new KAction(i18n("Highlight List"),0,0,this,SLOT (openHilight()),actionCollection(),"open_hilight_window");
@@ -57,18 +63,33 @@ ServerWindow::ServerWindow(Server* newServer) : KMainWindow()
 
   // Keyboard accelerators to navigate through the different pages
   KAccel* accelerator=accel();
-  accelerator->insert("Next Tab",i18n("Next Tab"),"Jump to next tab",KShortcut("Alt+Right"),this,SLOT(nextTab()));
-  accelerator->insert("Previous Tab",i18n("Previous Tab"),"Jump to previous tab",KShortcut("Alt+Left"),this,SLOT(previousTab()));
+  accelerator->insert("Next Tab",i18n("Next Tab"),i18n("Go to next tab"),KShortcut("Alt+Right"),this,SLOT(nextTab()));
+  accelerator->insert("Previous Tab",i18n("Previous Tab"),i18n("Go to previous tab"),KShortcut("Alt+Left"),this,SLOT(previousTab()));
+  accelerator->insert("Go to Tab 1",i18n("Tab %1").arg(1),i18n("Go to tab number %1").arg(1),KShortcut("Alt+1"),this,SLOT(goToTab0()));
+  accelerator->insert("Go to Tab 2",i18n("Tab %1").arg(2),i18n("Go to tab number %1").arg(2),KShortcut("Alt+2"),this,SLOT(goToTab1()));
+  accelerator->insert("Go to Tab 3",i18n("Tab %1").arg(3),i18n("Go to tab number %1").arg(3),KShortcut("Alt+3"),this,SLOT(goToTab2()));
+  accelerator->insert("Go to Tab 4",i18n("Tab %1").arg(4),i18n("Go to tab number %1").arg(4),KShortcut("Alt+4"),this,SLOT(goToTab3()));
+  accelerator->insert("Go to Tab 5",i18n("Tab %1").arg(5),i18n("Go to tab number %1").arg(5),KShortcut("Alt+5"),this,SLOT(goToTab4()));
+  accelerator->insert("Go to Tab 6",i18n("Tab %1").arg(6),i18n("Go to tab number %1").arg(6),KShortcut("Alt+6"),this,SLOT(goToTab5()));
+  accelerator->insert("Go to Tab 7",i18n("Tab %1").arg(7),i18n("Go to tab number %1").arg(7),KShortcut("Alt+7"),this,SLOT(goToTab6()));
+  accelerator->insert("Go to Tab 8",i18n("Tab %1").arg(8),i18n("Go to tab number %1").arg(8),KShortcut("Alt+8"),this,SLOT(goToTab7()));
+  accelerator->insert("Go to Tab 9",i18n("Tab %1").arg(9),i18n("Go to tab number %1").arg(9),KShortcut("Alt+9"),this,SLOT(goToTab8()));
+  accelerator->insert("Go to Tab 0",i18n("Tab %1").arg(0),i18n("Go to tab number %1").arg(0),KShortcut("Alt+0"),this,SLOT(goToTab9()));
 
   // Initialize KMainWindow->statusBar()
   statusBar();
   statusBar()->insertItem(i18n("Ready."),StatusText,1);
   statusBar()->insertItem("lagometer",LagOMeter,0,true);
+
   // Show "Lag unknown"
   resetLag();
   statusBar()->setItemAlignment(StatusText,QLabel::AlignLeft);
 
+  // Initialize KMainWindow->menuBar()
+  showMenubar();
+
   addStatusView();
+  if(KonversationApplication::preferences.getRawLog()) addRawLog();
 
   connect( windowContainer,SIGNAL (currentChanged(QWidget*)),this,SLOT (changedView(QWidget*)) );
   connect( windowContainer,SIGNAL (closeTab(QWidget*)),this,SLOT (closeTab(QWidget*)) );
@@ -83,6 +104,7 @@ ServerWindow::~ServerWindow()
 
   if(nicksOnlineWindow) nicksOnlineWindow->closeButton();
   deleteDccPanel();
+  if(rawLog) delete rawLog;
 }
 
 void ServerWindow::openPreferences()
@@ -98,6 +120,21 @@ void ServerWindow::showToolbar()
   KonversationApplication::preferences.serverWindowToolBarStatus=showToolBarAction->isChecked();
 }
 
+void ServerWindow::showMenubar()
+{
+  if(showMenuBarAction->isChecked()) menuBar()->show();
+  else
+  {
+    QString accel=showMenuBarAction->shortcut().toString();
+    KMessageBox::information(this,i18n("<qt>This will hide the menu bar completely."
+                                       "You can show it again by typing %1.</qt>").arg(accel),
+                                       "Hide menu bar","HideMenuBarWarning");
+    menuBar()->hide();
+  }
+
+  KonversationApplication::preferences.serverWindowMenuBarStatus=showMenuBarAction->isChecked();
+}
+
 void ServerWindow::showStatusbar()
 {
   if(showStatusBarAction->isChecked()) statusBar()->show();
@@ -115,22 +152,27 @@ void ServerWindow::setServer(Server* newServer)
     nicksOnlineWindow=0;
   }
 
-  server=newServer;
+  server_=newServer;
 
-  connect(this,SIGNAL (closeChannel(const QString&)),server,SLOT (closeChannel(const QString&)));
-  connect(this,SIGNAL (closeQuery(const QString&)),server,SLOT (closeQuery(const QString&)));
+  connect(this,SIGNAL (closeChannel(const QString&)),getServer(),SLOT (closeChannel(const QString&)));
+  connect(this,SIGNAL (closeQuery(const QString&)),getServer(),SLOT (closeQuery(const QString&)));
 }
 
 Server* ServerWindow::getServer()
 {
-  return server;
+  return server_;
 }
 
-void ServerWindow::setIdentity(const Identity& identity)
+void ServerWindow::setIdentity(const Identity *identity)
 {
   filter.setIdentity(identity);
 }
 
+void ServerWindow::appendToRaw(const QString& message)
+{
+  if(rawLog) rawLog->appendRaw(message);
+}
+
 void ServerWindow::appendToStatus(const QString& type,const QString& message)
 {
   statusPanel->appendServerMessage(type,message);
@@ -149,12 +191,12 @@ void ServerWindow::appendToFrontmost(const QString& type,const QString& message)
     frontView->appendServerMessage(type,message);
 }
 
-void ServerWindow::addView(QWidget* pane,int color,const QString& label)
+void ServerWindow::addView(QWidget* pane,int color,const QString& label,bool on)
 {
   // TODO: Make sure to add DCC status tab at the end of the list and all others
   // before the DCC tab. Maybe we should also make sure to order Channels
   // Queries and DCC chats in groups
-  windowContainer->addTab(pane,label,color,true);
+  windowContainer->addTab(pane,label,color,on);
   // TODO: Check, if user was typing in old input line
   if(KonversationApplication::preferences.getBringToFront())
   {
@@ -173,32 +215,6 @@ void ServerWindow::showView(QWidget* pane)
   }
 }
 
-void ServerWindow::nextTab()
-{
-  kdDebug() << "ServerWindow::nextTab()" << endl;
-
-  int page=windowContainer->currentPageIndex()+1;
-  if(page<windowContainer->count())
-  {
-    windowContainer->setCurrentPage(page);
-    ChatWindow* newPage=(ChatWindow*) windowContainer->page(page);
-    newPage->adjustFocus();
-  }
-}
-
-void ServerWindow::previousTab()
-{
-  kdDebug() << "ServerWindow::previousTab()" << endl;
-
-  int page=windowContainer->currentPageIndex()-1;
-  if(page!=-1)
-  {
-    windowContainer->setCurrentPage(page);
-    ChatWindow* newPage=(ChatWindow*) windowContainer->page(page);
-    newPage->adjustFocus();
-  }
-}
-
 void ServerWindow::closeTab(QWidget* viewToClose)
 {
   ChatWindow* view=(ChatWindow*) viewToClose;
@@ -209,7 +225,7 @@ void ServerWindow::closeTab(QWidget* viewToClose)
   {
     int result= KMessageBox::warningYesNo(
                   this,
-                  i18n("Do you really want to disconnect from %1?").arg(server->getIrcName()),
+                  i18n("Do you really want to disconnect from %1?").arg(getServer()->getIrcName()),
                   i18n("Quit server"),
                   KStdGuiItem::yes(),
                   KStdGuiItem::no(),
@@ -217,14 +233,17 @@ void ServerWindow::closeTab(QWidget* viewToClose)
 
     if(result==KMessageBox::Yes)
     {
-      QString command=filter.parse(server->getNickname(),KonversationApplication::preferences.getCommandChar()+"quit","");
-      server->queue(filter.getServerOutput());
+      QString command=filter.parse(getServer()->getNickname(),KonversationApplication::preferences.getCommandChar()+"quit",QString::null);
+      getServer()->queue(filter.getServerOutput());
     }
   }
   else if(viewType==ChatWindow::Channel)  emit closeChannel(viewName);
   else if(viewType==ChatWindow::Query)    emit closeQuery(viewName);
-  else if(viewType==ChatWindow::DccChat);
   else if(viewType==ChatWindow::DccPanel) closeDccPanel();
+  else if(viewType==ChatWindow::DccChat);
+  else if(viewType==ChatWindow::RawLog)   closeRawLog();
+  else if(viewType==ChatWindow::Notice);
+  else if(viewType==ChatWindow::SNotice);
 }
 
 void ServerWindow::addDccPanel()
@@ -235,6 +254,7 @@ void ServerWindow::addDccPanel()
     dccPanel=new DccPanel(getWindowContainer());
     addView(dccPanel,3,i18n("DCC Status"));
     dccPanelOpen=true;
+    connect(dccPanel,SIGNAL(requestDccSend()),getServer(),SLOT(requestDccSend()));
     kdDebug() << "ServerWindow::addDccPanel(): " << dccPanel << endl;
   }
   // show already opened panel
@@ -283,6 +303,31 @@ void ServerWindow::addStatusView()
   statusPanel->setIdentity(getServer()->getIdentity());
 
   connect(statusPanel,SIGNAL (newText(QWidget*)),this,SLOT (newText(QWidget*)) );
+  connect(statusPanel,SIGNAL (sendFile()),getServer(),SLOT (requestDccSend()) );
+}
+
+void ServerWindow::addRawLog()
+{
+  kdDebug() << "ServerWindow::addRawLog()" << endl;
+  if(rawLog==0)
+  {
+    rawLog=new RawLog(getWindowContainer());
+    addView(rawLog,2,i18n("Raw Log"),false);
+    
+    rawLog->setLog(false);
+  }
+  else
+    windowContainer->showPage(rawLog);
+}
+
+void ServerWindow::closeRawLog()
+{
+  if(rawLog)
+  {
+    getWindowContainer()->removePage(rawLog);
+    delete rawLog;
+    rawLog=0;
+  }
 }
 
 void ServerWindow::setNickname(const QString& newNickname)
@@ -305,9 +350,10 @@ void ServerWindow::changedView(QWidget* view)
 {
   frontView=0;
   
-  ChatWindow* pane=(ChatWindow*) view;
+  ChatWindow* pane=static_cast<ChatWindow*>(view);
   // Make sure that only text-capable views get to be the frontView
-  if(pane->getType()!=ChatWindow::DccPanel) frontView=pane;
+  if(pane->getType()!=ChatWindow::DccPanel &&
+     pane->getType()!=ChatWindow::RawLog) frontView=pane;
 
   windowContainer->changeTabState(view,false);
 }
@@ -325,6 +371,10 @@ void ServerWindow::readOptions()
   showStatusBarAction->setChecked(KonversationApplication::preferences.serverWindowStatusBarStatus);
   showStatusbar();
 
+  // Menu bar settings
+  showMenuBarAction->setChecked(KonversationApplication::preferences.serverWindowMenuBarStatus);
+  showMenubar();
+
   QSize size=KonversationApplication::preferences.getServerWindowSize();
   if(!size.isEmpty())
   {
@@ -345,12 +395,12 @@ void ServerWindow::saveOptions()
 bool ServerWindow::queryExit()
 {
   kdDebug() << "ServerWindow::queryExit()" << endl;
-  QString command=filter.parse(server->getNickname(),KonversationApplication::preferences.getCommandChar()+"quit","");
-  server->queue(filter.getServerOutput());
+  QString command=filter.parse(getServer()->getNickname(),KonversationApplication::preferences.getCommandChar()+"quit",QString::null);
+  getServer()->queue(filter.getServerOutput());
 
   saveOptions();
 
-  server->setServerWindow(0);
+  getServer()->setServerWindow(0);
   return true;
 }
 
@@ -403,7 +453,7 @@ void ServerWindow::applyButtons(QStringList newButtonList)
 {
   KonversationApplication::preferences.setButtonList(newButtonList);
   emit prefsChanged();
-  server->updateChannelQuickButtons(newButtonList);
+  getServer()->updateChannelQuickButtons(newButtonList);
 }
 
 void ServerWindow::closeButtons(QSize newButtonsSize)
@@ -463,7 +513,7 @@ void ServerWindow::applyNotify(QStringList newList,bool use,int delay)
   KonversationApplication::preferences.setUseNotify(use);
 
   // Restart notify timer if desired
-  if(use) server->startNotifyTimer();
+  if(use) getServer()->startNotifyTimer();
 
   emit prefsChanged();
 }
@@ -485,7 +535,7 @@ void ServerWindow::openNicksOnlineWindow()
     connect(nicksOnlineWindow,SIGNAL (editClicked()),this,SLOT (openNotify()) );
     connect(nicksOnlineWindow,SIGNAL (doubleClicked(QListViewItem*)),this,SLOT (notifyAction(QListViewItem*)) );
     connect(nicksOnlineWindow,SIGNAL (closeClicked(QSize)),this,SLOT (closeNicksOnlineWindow(QSize)) );
-    connect(server,SIGNAL (nicksNowOnline(QStringList)),nicksOnlineWindow,SLOT (setOnlineList(QStringList)) );
+    connect(getServer(),SIGNAL (nicksNowOnline(const QStringList&)),nicksOnlineWindow,SLOT (setOnlineList(const QStringList&)) );
     nicksOnlineWindow->show();
   }
 }
@@ -504,8 +554,8 @@ void ServerWindow::notifyAction(QListViewItem* item)
   if(item)
   {
     // parse wildcards (toParse,nickname,channelName,nickList,queryName,parameter)
-    QString out=server->parseWildcards(KonversationApplication::preferences.getNotifyDoubleClickAction(),
-                                       server->getNickname(),
+    QString out=getServer()->parseWildcards(KonversationApplication::preferences.getNotifyDoubleClickAction(),
+                                       getServer()->getNickname(),
                                        QString::null,
                                        QString::null,
                                        item->text(0),
@@ -515,8 +565,8 @@ void ServerWindow::notifyAction(QListViewItem* item)
     QStringList outList=QStringList::split('\n',out);
     for(unsigned int index=0;index<outList.count();index++)
     {
-      filter.parse(server->getNickname(),outList[index],QString::null);
-      server->queue(filter.getServerOutput());
+      filter.parse(getServer()->getNickname(),outList[index],QString::null);
+      getServer()->queue(filter.getServerOutput());
     } // endfor
   }
 }
@@ -627,4 +677,36 @@ bool ServerWindow::isFrontView(const ChatWindow* view)
   return(frontView==view);
 }
 
+void ServerWindow::nextTab()
+{
+  goToTab(windowContainer->currentPageIndex()+1);
+}
+
+void ServerWindow::previousTab()
+{
+  goToTab(windowContainer->currentPageIndex()-1);
+}
+
+void ServerWindow::goToTab(int page)
+{
+  if(page>=0 && page<windowContainer->count())
+  {
+    windowContainer->setCurrentPage(page);
+    ChatWindow* newPage=(ChatWindow*) windowContainer->page(page);
+    newPage->adjustFocus();
+  }
+}
+
+// I hope we can find a better way soon ... this is ridiculous"
+void ServerWindow::goToTab0() { goToTab(0); }
+void ServerWindow::goToTab1() { goToTab(1); }
+void ServerWindow::goToTab2() { goToTab(2); }
+void ServerWindow::goToTab3() { goToTab(3); }
+void ServerWindow::goToTab4() { goToTab(4); }
+void ServerWindow::goToTab5() { goToTab(5); }
+void ServerWindow::goToTab6() { goToTab(6); }
+void ServerWindow::goToTab7() { goToTab(7); }
+void ServerWindow::goToTab8() { goToTab(8); }
+void ServerWindow::goToTab9() { goToTab(9); }
+
 #include "serverwindow.moc"
