@@ -11,7 +11,7 @@
   copyright: (C) 2003 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: statuspanel.cpp,v 1.5 2003/02/16 20:03:01 eisfuchs Exp $
+  $Id: statuspanel.cpp,v 1.9 2003/03/12 22:11:16 eisfuchs Exp $
 */
 
 #include <kdebug.h>
@@ -28,6 +28,7 @@ StatusPanel::StatusPanel(QWidget* parent) :
   kdDebug() << "StatusPanel::StatusPanel()" << endl;
 
   setType(ChatWindow::Status);
+  setName(QString::null);             // empty name for scripts
 
   // set up text view, will automatically take care of logging
   setTextView(new IRCView(this,NULL));  // Server will be set later in setServer()
@@ -45,6 +46,8 @@ StatusPanel::StatusPanel(QWidget* parent) :
   setLogfileName("konversation.log");
 
   connect(getTextView(),SIGNAL (gotFocus()),statusInput,SLOT (setFocus()) );
+
+  connect(getTextView(),SIGNAL (sendFile()),this,SLOT (sendFileMenu()) );
 //  connect(getTextView(),SIGNAL (textToLog(const QString&)),this,SLOT (logText(const QString&)) );
 
   connect(statusInput,SIGNAL (returnPressed()),this,SLOT(statusTextEntered()) );
@@ -71,9 +74,9 @@ void StatusPanel::sendStatusText(QString sendLine)
   QTextCodec* codec=QTextCodec::codecForLocale();
   QCString line=codec->fromUnicode(sendLine);
 
-  QString output=filter.parse(server->getNickname(),line,"");
+  QString output=filter.parse(server->getNickname(),line, QString::null);
 
-  if(output!="") appendServerMessage(filter.getType(),output);
+  if(!output.isEmpty()) appendServerMessage(filter.getType(),output);
 
   server->queue(filter.getServerOutput());
 }
@@ -110,8 +113,14 @@ void StatusPanel::updateFonts()
 {
   kdDebug() << "StatusPanel::updateFonts()" << endl;
 
+  statusInput->setFont(KonversationApplication::preferences.getTextFont());
   getTextView()->setFont(KonversationApplication::preferences.getTextFont());
   getTextView()->setPaper(QColor("#"+KonversationApplication::preferences.getTextViewBackground()));
 }
 
+void StatusPanel::sendFileMenu()
+{
+  emit sendFile();
+}
+
 #include "statuspanel.moc"
