@@ -11,7 +11,7 @@
   copyright: (C) 2003 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: statuspanel.h,v 1.1 2003/01/18 18:58:59 eisfuchs Exp $
+  $Id: statuspanel.h,v 1.2 2003/03/02 15:51:45 eisfuchs Exp $
 */
 
 #ifndef STATUSPANEL_H
@@ -37,6 +37,7 @@ class StatusPanel : public ChatWindow
 
   signals:
     void newText(QWidget* widget);
+    void sendFile();
     
   public slots:
     void adjustFocus();
@@ -45,6 +46,7 @@ class StatusPanel : public ChatWindow
     void updateFonts();
 
   protected slots:
+    void sendFileMenu();
     void statusTextEntered();
     // connected to IRCInput::textPasted() - used for large/multiline pastes
     void textPasted(QString text);
